@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@
 */
 
 #include "SensorFactory.hpp"
-#include "RuntimeException.hpp"
+#include "SiconosException.hpp"
 
 
 
@@ -40,7 +40,7 @@ SP::Sensor Registry::instantiate(int type, SP::DynamicalSystem ds)
   MapFactoryIt it = factory_map.find(type) ;
 
   if(it == factory_map.end())
-    RuntimeException::selfThrow("Registry::instantiate (SensorFactory) failed, no class named: " + std::to_string(type));
+    THROW_EXCEPTION("Registry::instantiate (SensorFactory) failed, no class named: " + std::to_string(type));
 
   return (it->second)(ds) ;  // run our factory
 }
