@@ -4,6 +4,12 @@ import sys
 from math import cos, sin, asin, atan2
 import numpy as np
 import h5py
+## fix compatibility with h5py version
+if (h5py.version.version_tuple.major >=3 ):
+    h5py_vlen_dtype = h5py.vlen_dtype
+else:
+    h5py_vlen_dtype = h5py.new_vlen
+
 import pickle
 import tempfile
 from contextlib import contextmanager
@@ -678,7 +684,7 @@ class MechanicsHdf5(object):
 
         if name not in self._plugins:
             plugin_src = self._plugins.create_dataset(name, (1,),
-                                                      dtype=h5py.new_vlen(str))
+                                                      dtype=h5py_vlen_dtype(str))
             plugin_src[:] = str_of_file(filename)
             plugin_src.attrs['filename'] = filename
 
@@ -712,7 +718,7 @@ class MechanicsHdf5(object):
         if name not in self._ref:
 
             shape = self._ref.create_dataset(name, (1,),
-                                             dtype=h5py.new_vlen(str))
+                                             dtype=h5py_vlen_dtype(str))
             shape[:] = shape_data
             shape.attrs['id'] = self._number_of_shapes
             shape.attrs['type'] = 'vtp'
@@ -793,7 +799,7 @@ class MechanicsHdf5(object):
         """
         if name not in self._ref:
             shape = self._ref.create_dataset(name, (1,),
-                                             dtype=h5py.new_vlen(str))
+                                             dtype=h5py_vlen_dtype(str))
             if type(shape_data) == str:
                 # raw str
                 shape[:] = shape_data
@@ -831,7 +837,7 @@ class MechanicsHdf5(object):
                 shape_data = str_of_file(tmpf[1])
 
                 shape = self._ref.create_dataset(name, (1,),
-                                                 dtype=h5py.new_vlen(str))
+                                                 dtype=h5py_vlen_dtype(str))
                 shape[:] = shape_data
                 shape.attrs['id'] = self._number_of_shapes
                 shape.attrs['type'] = 'step'
@@ -843,7 +849,7 @@ class MechanicsHdf5(object):
         """
         if name not in self._ref:
             shape = self._ref.create_dataset(name, (1,),
-                                             dtype=h5py.new_vlen(str))
+                                             dtype=h5py_vlen_dtype(str))
             shape[:] = str_of_file(filename)
             shape.attrs['id'] = self._number_of_shapes
             try:
@@ -862,7 +868,7 @@ class MechanicsHdf5(object):
         """
         if name not in self.permanent_interactions():
             pinter = self.permanent_interactions().create_dataset(
-                name, (1,), dtype=h5py.new_vlen(str))
+                name, (1,), dtype=h5py_vlen_dtype(str))
             pinter.attrs['id'] = self._number_of_permanent_interactions
             pinter.attrs['type'] = 'permanent_interaction'
             pinter.attrs['body1_name'] = body1_name
@@ -937,12 +943,22 @@ class MechanicsHdf5(object):
                    use_volume_centroid_as_initial_translation=False,
                    mass=None, center_of_mass=[0, 0, 0], inertia=None,
                    time_of_birth=-1, time_of_death=-1,
+                   fext=None,
                    allow_self_collide=False):
         """Add an object with associated shapes as a list of Volume or
         Contactor objects. Contact detection and processing is
         defined by the Contactor objects. The Volume objects are used for
         the computation of inertia and center of mass if not provided.
 
+        The  body-fixed frame is assumed to be the global inertial
+        frame. This means that 
+        1. By default, the center of mass is located at the origin. 
+        The initial translation is applied from this point, so that x_g(0) = translation
+        2. the  orientation is identical to the inertial frame. 
+        The initial orientation is applied to the inertial frame to obtain
+        the body-fixed frame.
+
+
         Each Contactor and Volume object may have a relative
         translation and a relative orientation expressed in the bodyframe
         coordinates.
@@ -1021,18 +1037,18 @@ class MechanicsHdf5(object):
                                      shapes)
 
                     computed_mass, com, computed_inertia, computed_inertia_matrix = compute_inertia_and_center_of_mass(volumes, self)
-                    print('{0}: computed mass from Volume'.format(name))
-                    print('{0}: computed center of mass:'.format(name),
-                          com[0],
-                          com[1],
-                          com[2])
-                    print('{0}: computed mass:'.format(name),
-                          computed_mass)
-                    print('{0}: computed inertia:'.format(name),
-                          computed_inertia[0], computed_inertia[1],
-                          computed_inertia[2])
-                    print('{0}: computed inertia matrix:'.format(name),
-                          computed_inertia_matrix)
+                    self.print_verbose('{0}: computed mass from Volume'.format(name))
+                    self.print_verbose('{0}: computed center of mass:'.format(name),
+                                       com[0],
+                                       com[1],
+                                       com[2])
+                    self.print_verbose('{0}: computed mass:'.format(name),
+                                       computed_mass)
+                    self.print_verbose('{0}: computed inertia:'.format(name),
+                                       computed_inertia[0], computed_inertia[1],
+                                       computed_inertia[2])
+                    self.print_verbose('{0}: computed inertia matrix:'.format(name),
+                                       computed_inertia_matrix)
                     is_center_of_mass_computed = True
                     if mass is None:
                         mass = computed_mass
@@ -1068,6 +1084,10 @@ class MechanicsHdf5(object):
 
             if inertia is not None:
                 obj.attrs['inertia'] = inertia
+
+            if fext is not None:
+                obj.attrs['fext'] = fext
+
             if allow_self_collide is not None:
                 obj.attrs['allow_self_collide'] = allow_self_collide
 
