@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@
 
 //#define DEBUG_MESSAGES
 //#define DEBUG_STDOUT
-#include "debug.h"
+#include "siconos_debug.h"
 
 FixedBC::FixedBC(SP::UnsignedIntVector newVelocityIndices) :
   BoundaryCondition(newVelocityIndices)
