@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@
 // #define DEBUG_STDOUT
 // #define DEBUG_NOCOLOR
 // #define DEBUG_MESSAGES
-#include "debug.h"
+#include "siconos_debug.h"
 #include "SiconosMatrixSetBlock.hpp"
 #include "Interaction.hpp"
 #include "RelationTypes.hpp"
@@ -44,6 +44,9 @@
 
 #include "SimulationGraphs.hpp"
 
+// Test : the following line is allowed only from C++17.
+#include <variant>
+
 using namespace std;
 using namespace RELATION;
 
@@ -86,7 +89,7 @@ struct Interaction::_setLevels : public SiconosVisitor
     }
     else
     {
-      RuntimeException::selfThrow("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
+      THROW_EXCEPTION("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
     };
   }
 
@@ -112,7 +115,7 @@ struct Interaction::_setLevels : public SiconosVisitor
     }
     else
     {
-      RuntimeException::selfThrow("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
+      THROW_EXCEPTION("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
     };
   }
 
@@ -129,7 +132,7 @@ struct Interaction::_setLevels : public SiconosVisitor
     }
     else
     {
-      RuntimeException::selfThrow("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
+      THROW_EXCEPTION("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
     };
   }
 
@@ -146,7 +149,7 @@ struct Interaction::_setLevels : public SiconosVisitor
     }
     else
     {
-      RuntimeException::selfThrow("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
+      THROW_EXCEPTION("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
     };
   }
 
@@ -172,7 +175,7 @@ struct Interaction::_setLevels : public SiconosVisitor
     }
     else
     {
-      RuntimeException::selfThrow("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
+      THROW_EXCEPTION("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
     }
     ;
   }
@@ -190,7 +193,7 @@ struct Interaction::_setLevels : public SiconosVisitor
     }
     else
     {
-      RuntimeException::selfThrow("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
+      THROW_EXCEPTION("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
     }
   }
 
@@ -208,7 +211,7 @@ struct Interaction::_setLevels : public SiconosVisitor
     }
     else
     {
-      RuntimeException::selfThrow("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
+      THROW_EXCEPTION("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
     }
   }
   void visit(const NewtonImpactRollingFrictionNSL& nslaw)
@@ -225,7 +228,7 @@ struct Interaction::_setLevels : public SiconosVisitor
     }
     else
     {
-      RuntimeException::selfThrow("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
+      THROW_EXCEPTION("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
     }
   }
   void visit(const MultipleImpactNSL& nslaw)
@@ -242,7 +245,7 @@ struct Interaction::_setLevels : public SiconosVisitor
     }
     else
     {
-      RuntimeException::selfThrow("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
+      THROW_EXCEPTION("Interaction::_setLevels::visit - unknown relation type for the nslaw ");
     }
   }
 };
@@ -320,7 +323,7 @@ Interaction::Interaction(SP::NonSmoothLaw NSL, SP::Relation rel):
 
   // Ensure consistency between interaction and nslaw sizes
   if(_interactionSize != _nslaw->size())
-    RuntimeException::selfThrow("Interaction constructor - Nonsmooth law and relation are not consistent (sizes differ).");
+    THROW_EXCEPTION("Interaction constructor - Nonsmooth law and relation are not consistent (sizes differ).");
 
   // Check levels and resize attributes (y, lambda ...) if needed.
   reset();
@@ -345,7 +348,7 @@ void Interaction::initializeLinkToDsVariables(DynamicalSystem& ds1,
     __initDataNewtonEuler(DSlink, ds1, ds2);
 
   else
-    RuntimeException::selfThrow("Interaction::initData unknown initialization procedure for \
+    THROW_EXCEPTION("Interaction::initData unknown initialization procedure for \
         a relation of type: " + std::to_string(relationType));
 
   _relation->initialize(*this);
@@ -548,12 +551,12 @@ void Interaction::__initDSDataNewtonEuler(DynamicalSystem& ds, VectorOfBlockVect
 void Interaction::setY(const VectorOfVectors& newVector)
 {
 
-  unsigned int size = newVector.size();
+  auto size = newVector.size();
 
   _y.clear();
   _y.resize(size);
 
-  for(unsigned int i = 0; i < size; i++)
+  for(VectorOfVectors::size_type i = 0; i < size; i++)
     _y[i].reset(new SiconosVector(*(newVector[i]))); // -> copy !
 }
 
@@ -596,11 +599,11 @@ void Interaction::setYPtr(const unsigned int  index, SP::SiconosVector newY)
 
 void Interaction::setYOld(const VectorOfVectors& newVector)
 {
-  unsigned int size = newVector.size();
+  auto size = newVector.size();
   _yOld.clear();
   _yOld.resize(size);
 
-  for(unsigned int i = 0; i < size; i++)
+  for(VectorOfVectors::size_type i = 0; i < size; i++)
     _yOld[i].reset(new SiconosVector(*(newVector[i]))); // -> copy !
 }
 
@@ -617,7 +620,7 @@ void Interaction::setYOldPtr(const VectorOfVectors& newVector)
 void Interaction::setYOld(const unsigned int  index, const SiconosVector& newYOld)
 {
   if(_yOld.size() <= index)
-    RuntimeException::selfThrow("Interaction::setYOld, index out of range ");
+    THROW_EXCEPTION("Interaction::setYOld, index out of range ");
 
   // set _yOld[index]
   if(! _yOld[index])
@@ -645,11 +648,11 @@ void Interaction::setYOldPtr(const unsigned int  index, SP::SiconosVector newYOl
 
 void Interaction::setLambda(const VectorOfVectors& newVector)
 {
-  unsigned int size = newVector.size();
+  auto size = newVector.size();
   _lambda.clear();
   _lambda.resize(size);
 
-  for(unsigned int i = 0; i < size; i++)
+  for(VectorOfVectors::size_type i = 0; i < size; i++)
     _lambda[i].reset(new SiconosVector(*(newVector[i]))); // -> copy !
 }
 
@@ -691,13 +694,13 @@ void Interaction::setLambdaPtr(const unsigned int  index, SP::SiconosVector newL
 
 void Interaction::setLambdaOld(const VectorOfVectors& newVector)
 {
-  unsigned int size = newVector.size();
+  auto size = newVector.size();
 
   // clear lambdaOld
   _lambdaOld.clear();
   _lambdaOld.resize(size);
 
-  for(unsigned int i = 0; i < size; i++)
+  for(VectorOfVectors::size_type i = 0; i < size; i++)
     _lambdaOld[i].reset(new SiconosVector(*(newVector[i]))); // -> copy !
 }
 
@@ -723,7 +726,7 @@ void Interaction::setLambdaOld(const unsigned int  index, const SiconosVector& n
   else
   {
     if(_lambdaOld[index]->size() != newLambdaOld.size())
-      RuntimeException::selfThrow("Interaction::setLambdaOld(index,newLambdaOld), inconsistent sizes between lambdaOld(index) and newLambdaOld ");
+      THROW_EXCEPTION("Interaction::setLambdaOld(index,newLambdaOld), inconsistent sizes between lambdaOld(index) and newLambdaOld ");
     *(_lambdaOld[index]) = newLambdaOld;
   }
 }
@@ -731,9 +734,9 @@ void Interaction::setLambdaOld(const unsigned int  index, const SiconosVector& n
 void Interaction::setLambdaOldPtr(const unsigned int  index, SP::SiconosVector newLambdaOld)
 {
   if(_lambdaOld.size() > index)
-    RuntimeException::selfThrow("Interaction::setLambdaOldPtr, index out of range ");
+    THROW_EXCEPTION("Interaction::setLambdaOldPtr, index out of range ");
   if(newLambdaOld->size() != _interactionSize)
-    RuntimeException::selfThrow("Interaction::setLambdaOldPtr, interactionSize differs from newLambdaOld vector size ");
+    THROW_EXCEPTION("Interaction::setLambdaOldPtr, interactionSize differs from newLambdaOld vector size ");
 
   _lambdaOld[index] = newLambdaOld;
 }
@@ -871,7 +874,7 @@ void Interaction::computeInput(double time,  unsigned int level)
 
 
 
-void Interaction::getLeftInteractionBlockForDS(unsigned int pos, SP::SiconosMatrix InteractionBlock) const
+SP::SiconosMatrix Interaction::getLeftInteractionBlockForDS(unsigned int pos, unsigned size, unsigned int  sizeDS) const
 {
   SP::SiconosMatrix originalMatrix;
   RELATION::TYPES relationType = relation()->getType();
@@ -896,7 +899,9 @@ void Interaction::getLeftInteractionBlockForDS(unsigned int pos, SP::SiconosMatr
     originalMatrix = r->jachqT();
   }
   else
-    RuntimeException::selfThrow("Interaction::getLeftInteractionBlockForDS, not yet implemented for relations of type " + std::to_string(relationType));
+    THROW_EXCEPTION("Interaction::getLeftInteractionBlockForDS, not yet implemented for relations of type " + std::to_string(relationType));
+//  Siconos::UBLAS_TYPE type = originalMatrix->num();
+  SP::SiconosMatrix  InteractionBlock(new SimpleMatrix(size, sizeDS, originalMatrix->num() ));
 
   // copy sub-interactionBlock of originalMatrix into InteractionBlock
   // dim of the sub-interactionBlock
@@ -911,6 +916,7 @@ void Interaction::getLeftInteractionBlockForDS(unsigned int pos, SP::SiconosMatr
   subPos[2] = 0;
   subPos[3] = 0;
   setBlock(originalMatrix, InteractionBlock, subDim, subPos);
+  return InteractionBlock;
 }
 
 void Interaction::getLeftInteractionBlockForDSProjectOnConstraints(unsigned int pos, SP::SiconosMatrix InteractionBlock) const
@@ -924,11 +930,11 @@ void Interaction::getLeftInteractionBlockForDSProjectOnConstraints(unsigned int
 
   //Type::Siconos dsType = Type::value(*ds);
   //if (dsType != Type::NewtonEulerDS)
-  //  RuntimeException::selfThrow("Interaction::getLeftInteractionBlockForDSForProject- ds is not from NewtonEulerDS.");
+  //  THROW_EXCEPTION("Interaction::getLeftInteractionBlockForDSForProject- ds is not from NewtonEulerDS.");
 
   RELATION::TYPES relationType = relation()->getType();
   if(relationType != NewtonEuler)
-    RuntimeException::selfThrow("Interaction::getLeftInteractionBlockForDSForProject- relation is not from NewtonEulerR.");
+    THROW_EXCEPTION("Interaction::getLeftInteractionBlockForDSForProject- relation is not from NewtonEulerR.");
 
   SP::SiconosMatrix originalMatrix;
   SP::NewtonEulerR r = std::static_pointer_cast<NewtonEulerR> (relation());
@@ -950,7 +956,7 @@ void Interaction::getLeftInteractionBlockForDSProjectOnConstraints(unsigned int
   setBlock(originalMatrix, InteractionBlock, subDim, subPos);
 }
 
-void Interaction::getRightInteractionBlockForDS(unsigned int pos, SP::SiconosMatrix InteractionBlock) const
+SP::SiconosMatrix Interaction::getRightInteractionBlockForDS(unsigned int pos, unsigned int sizeDS, unsigned int size ) const
 {
   SP::SiconosMatrix originalMatrix; // Complete matrix, Relation member.
   RELATION::TYPES relationType = relation()->getType();
@@ -964,17 +970,19 @@ void Interaction::getRightInteractionBlockForDS(unsigned int pos, SP::SiconosMat
     else if(relationSubType != LinearTIR)
       originalMatrix = _relationMatrices[FirstOrderR::mat_B];
     else
-      RuntimeException::selfThrow("Interaction::getRightInteractionBlockForDS, FirstOrderLinearTIR relation but no B matrix found!");
+      THROW_EXCEPTION("Interaction::getRightInteractionBlockForDS, FirstOrderLinearTIR relation but no B matrix found!");
   }
   else if(relationType == Lagrangian || relationType == NewtonEuler)
   {
-    RuntimeException::selfThrow("Interaction::getRightInteractionBlockForDS, call not permit " + std::to_string(relationType));
+    THROW_EXCEPTION("Interaction::getRightInteractionBlockForDS, call not permit " + std::to_string(relationType));
   }
   else
-    RuntimeException::selfThrow("Interaction::getRightInteractionBlockForDS, not yet implemented for relations of type " + std::to_string(relationType));
+    THROW_EXCEPTION("Interaction::getRightInteractionBlockForDS, not yet implemented for relations of type " + std::to_string(relationType));
+
+  SP::SiconosMatrix  InteractionBlock(new SimpleMatrix(sizeDS, size, originalMatrix->num() ));
 
   if(! originalMatrix)
-    RuntimeException::selfThrow("Interaction::getRightInteractionBlockForDS(DS, InteractionBlock, ...): the right interactionBlock is a nullptr pointer (miss matrix B or H or gradients ...in relation ?)");
+    THROW_EXCEPTION("Interaction::getRightInteractionBlockForDS(DS, InteractionBlock, ...): the right interactionBlock is a nullptr pointer (miss matrix B or H or gradients ...in relation ?)");
 
   // copy sub-interactionBlock of originalMatrix into InteractionBlock
   // dim of the sub-interactionBlock
@@ -989,6 +997,7 @@ void Interaction::getRightInteractionBlockForDS(unsigned int pos, SP::SiconosMat
   subPos[2] = 0;
   subPos[3] = 0;
   setBlock(originalMatrix, InteractionBlock, subDim, subPos);
+  return InteractionBlock;
 }
 
 void Interaction::getExtraInteractionBlock(SP::SiconosMatrix InteractionBlock) const
@@ -1019,7 +1028,7 @@ void Interaction::getExtraInteractionBlock(SP::SiconosMatrix InteractionBlock) c
     D = std::static_pointer_cast<NewtonEulerR> (relation())->jachlambda();
   }
   else
-    RuntimeException::selfThrow("Interaction::getExtraInteractionBlockForDS, not yet implemented for relations of type " + std::to_string(relationType));
+    THROW_EXCEPTION("Interaction::getExtraInteractionBlockForDS, not yet implemented for relations of type " + std::to_string(relationType));
 
   if(!D)
   {
@@ -1029,4 +1038,3 @@ void Interaction::getExtraInteractionBlock(SP::SiconosMatrix InteractionBlock) c
 
   *InteractionBlock = *D;
 }
-
