@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -661,9 +661,9 @@ public:
   /** reset the global Interaction counter (for ids)
    *  \return the previous value of count
    */
-  static inline int resetCount(int new_count=0)
+  static inline size_t resetCount(size_t new_count=0)
   {
-    int old_count = __count;
+    size_t old_count = __count;
     __count = new_count;
     return old_count;
   };
@@ -683,10 +683,12 @@ public:
 
   /** gets the matrix used in interactionBlock computation, (left * W * right), depends on the relation type (ex, LinearTIR, left = C, right = B).
    *         We get only the part corresponding to one ds.
-   *  \param pos int, relative position of the beginning of the required block in relation matrix.
-   *  \param InteractionBlock a pointer to SiconosMatrix (in-out parameter): the resulting interactionBlock matrix
+   * \param pos int, relative position of the beginning of the required block in relation matrix.
+   * \param size int, size(0) of the block
+   * \param sizeDS int, size(1) of the block
+   *  \return InteractionBlock a pointer to SiconosMatrix (in-out parameter): the resulting interactionBlock matrix
    */
-  void getLeftInteractionBlockForDS(unsigned int pos, SP::SiconosMatrix InteractionBlock) const;
+  SP::SiconosMatrix getLeftInteractionBlockForDS(unsigned int pos, unsigned int size,  unsigned int sizeDS) const;
 
   /** gets the matrix used in interactionBlock computation. Used only for the formulation projecting on the constraints.
    *         We get only the part corresponding to ds.
@@ -697,10 +699,12 @@ public:
 
   /** gets the matrix used in interactionBlock computation, (left * W * rigth), depends on the relation type (ex, LinearTIR, left = C, right = B).
    *         We get only the part corresponding to ds.
-   *  \param pos int, relative position of the beginning of the required block in relation matrix.
-   *  \param InteractionBlock a pointer to SiconosMatrix (in-out parameter): the resulting interactionBlock matrix
+   * \param pos int, relative position of the beginning of the required block in relation matrix.
+   * \param sizeDS int, size(0) of the block
+   * \param size int, size(1) of the block
+   * \return InteractionBlock a pointer to SiconosMatrix (in-out parameter): the resulting interactionBlock matrix
    */
-  void getRightInteractionBlockForDS(unsigned int pos, SP::SiconosMatrix InteractionBlock) const;
+  SP::SiconosMatrix  getRightInteractionBlockForDS(unsigned int pos, unsigned int sizeDS, unsigned size) const;
 
   /** gets extra interactionBlock corresponding to the present Interaction (see the
    *  top of this files for extra interactionBlock meaning)
