@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,12 +21,12 @@
 // #define DEBUG_NOCOLOR
 // #define DEBUG_STDOUT
 // #define DEBUG_MESSAGES
-#include "debug.h"
+#include "siconos_debug.h"
 #include <iostream>
 
 void SecondOrderDS::setBoundaryConditions(SP::BoundaryCondition newbd)
 {
-  if(!_boundaryConditions)
+  if(_boundaryConditions)
   {
     std::cout << "Warning : SecondOrderDS::setBoundaryConditions. old boundary conditions were pre-existing" <<std::endl;
   }
