@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -34,7 +34,7 @@
 // #define DEBUG_NOCOLOR
 // #define DEBUG_STDOUT
 // #define DEBUG_MESSAGES
-#include "debug.h"
+#include "siconos_debug.h"
 
 
 #define D1MINUSLINEAR_STD
@@ -91,7 +91,7 @@ void D1MinusLinearOSI::setTypeOfD1MinusLinearOSI(unsigned int type)
   }
   else
   {
-    RuntimeException::selfThrow("D1MinusLinearOSI::setTypeOfD1MinusLinearOSI");
+    THROW_EXCEPTION("D1MinusLinearOSI::setTypeOfD1MinusLinearOSI");
   }
 }
 
@@ -108,7 +108,7 @@ unsigned int D1MinusLinearOSI::numberOfIndexSets() const
   case halfexplicit_velocity_level:
     return 3;
   }
-  RuntimeException::selfThrow("D1MinusLinearOSI::numberOfIndexSet - not implemented for D1minusLinear of type: " + std::to_string(_typeOfD1MinusLinearOSI));
+  THROW_EXCEPTION("D1MinusLinearOSI::numberOfIndexSet - not implemented for D1minusLinear of type: " + std::to_string(_typeOfD1MinusLinearOSI));
   return 0;
 }
 void D1MinusLinearOSI::initializeWorkVectorsForDS(double t, SP::DynamicalSystem ds)
@@ -147,7 +147,7 @@ void D1MinusLinearOSI::initializeWorkVectorsForDS(double t, SP::DynamicalSystem
     neds->swapInMemory();
   }
   else
-    RuntimeException::selfThrow("D1MinusLinearOSI::initialize - not implemented for Dynamical system type: " + std::to_string(dsType));
+    THROW_EXCEPTION("D1MinusLinearOSI::initialize - not implemented for Dynamical system type: " + std::to_string(dsType));
 
   for(unsigned int k = _levelMinForInput ; k < _levelMaxForInput + 1; k++)
   {
@@ -201,7 +201,7 @@ void D1MinusLinearOSI::initialize_nonsmooth_problems()
 
   if(!isOSNSPinitialized)
   {
-    RuntimeException::selfThrow("D1MinusLinearOSI::initialize() - not implemented for type of D1MinusLinearOSI: " + std::to_string(_typeOfD1MinusLinearOSI));
+    THROW_EXCEPTION("D1MinusLinearOSI::initialize() - not implemented for type of D1MinusLinearOSI: " + std::to_string(_typeOfD1MinusLinearOSI));
   }
 }
 
@@ -252,7 +252,7 @@ void D1MinusLinearOSI::initializeWorkVectorsForInteraction(Interaction &inter,
               << checkOSI(DSG.descriptor(ds2)) << std::endl;
 
 
-    RuntimeException::selfThrow("D1MinusLinearOSI::initializeWorkVectorsForInteraction. The implementation is not correct for two different OSI for one interaction");
+    THROW_EXCEPTION("D1MinusLinearOSI::initializeWorkVectorsForInteraction. The implementation is not correct for two different OSI for one interaction");
   }
 
 
@@ -348,7 +348,7 @@ double D1MinusLinearOSI::computeResidu()
     DEBUG_END("D1MinusLinearOSI::computeResidu()\n");
     return computeResiduHalfExplicitVelocityLevel();
   }
-  RuntimeException::selfThrow("D1MinusLinearOSI::computeResidu() - not implemented for type of D1MinusLinearOSI: " + std::to_string(_typeOfD1MinusLinearOSI));
+  THROW_EXCEPTION("D1MinusLinearOSI::computeResidu() - not implemented for type of D1MinusLinearOSI: " + std::to_string(_typeOfD1MinusLinearOSI));
   DEBUG_END("D1MinusLinearOSI::computeResidu()\n");
   return 1;
 }
@@ -382,8 +382,8 @@ void D1MinusLinearOSI::computeFreeState()
       vfree =  residuFree;
       DEBUG_EXPR(residuFree.display());
       // d->computeMass();
-      // M->resetLU();
-      // M->PLUForwardBackwardInPlace(vfree);
+      // M->resetFactorizationFlags();
+      // M->Solve(vfree);
       // DEBUG_EXPR(M->display());
 
       vfree *= -1.;
@@ -415,7 +415,7 @@ void D1MinusLinearOSI::computeFreeState()
 
     }
     else
-      RuntimeException::selfThrow("D1MinusLinearOSI::computeResidu - not yet implemented for Dynamical system type: " + std::to_string(dsType));
+      THROW_EXCEPTION("D1MinusLinearOSI::computeResidu - not yet implemented for Dynamical system type: " + std::to_string(dsType));
 
   }
 
@@ -459,7 +459,7 @@ void D1MinusLinearOSI::updateState(const unsigned int)
         if(d->inverseMass())
         {
           d->update_inverse_mass();
-          d->inverseMass()->PLUForwardBackwardInPlace(*dummy);
+          d->inverseMass()->Solve(*dummy);
         }
         /* Add the velocity jump to the free velocity */
         *v += *dummy;
@@ -482,7 +482,7 @@ void D1MinusLinearOSI::updateState(const unsigned int)
         if(d->inverseMass())
         {
           d->update_inverse_mass();
-          d->inverseMass()->PLUForwardBackwardInPlace(*dummy);
+          d->inverseMass()->Solve(*dummy);
         }
         *v += *dummy; // add free velocity
 
@@ -498,7 +498,7 @@ void D1MinusLinearOSI::updateState(const unsigned int)
       DEBUG_EXPR(d->velocity()->display());
     }
     else
-      RuntimeException::selfThrow("D1MinusLinearOSI::computeResidu - not yet implemented for Dynamical system type: " + std::to_string(dsType));
+      THROW_EXCEPTION("D1MinusLinearOSI::computeResidu - not yet implemented for Dynamical system type: " + std::to_string(dsType));
 
   }
 
@@ -526,7 +526,7 @@ void D1MinusLinearOSI::computeFreeOutput(InteractionsGraph::VDescriptor& vertex_
     DEBUG_END("D1MinusLinearOSI::computeFreeOutput()\n");
     return;
   }
-  RuntimeException::selfThrow("D1MinusLinearOSI::computeResidu() - not implemented for type of D1MinusLinearOSI: " + std::to_string(_typeOfD1MinusLinearOSI));
+  THROW_EXCEPTION("D1MinusLinearOSI::computeResidu() - not implemented for type of D1MinusLinearOSI: " + std::to_string(_typeOfD1MinusLinearOSI));
   DEBUG_END("D1MinusLinearOSI::computeFreeOutput()\n");
 }
 
@@ -543,7 +543,7 @@ bool D1MinusLinearOSI::addInteractionInIndexSet(SP::Interaction inter, unsigned
   case halfexplicit_velocity_level:
     return addInteractionInIndexSetHalfExplicitVelocityLevel(inter,i);
   }
-  RuntimeException::selfThrow("D1MinusLinearOSI::addInteractionInIndexSet() - not implemented for type of D1MinusLinearOSI: " + std::to_string(_typeOfD1MinusLinearOSI));
+  THROW_EXCEPTION("D1MinusLinearOSI::addInteractionInIndexSet() - not implemented for type of D1MinusLinearOSI: " + std::to_string(_typeOfD1MinusLinearOSI));
 
   return 0;
 }
@@ -559,13 +559,13 @@ bool D1MinusLinearOSI::removeInteractionFromIndexSet(SP::Interaction inter, unsi
   case halfexplicit_velocity_level:
     return removeInteractionFromIndexSetHalfExplicitVelocityLevel(inter,i);
   }
-  RuntimeException::selfThrow("D1MinusLinearOSI::removeInteractionFromIndexSet() - not implemented for type of D1MinusLinearOSI: " + std::to_string(_typeOfD1MinusLinearOSI));
+  THROW_EXCEPTION("D1MinusLinearOSI::removeInteractionFromIndexSet() - not implemented for type of D1MinusLinearOSI: " + std::to_string(_typeOfD1MinusLinearOSI));
   return 0;
 }
 
 
 double D1MinusLinearOSI::computeResiduHalfExplicitAccelerationLevelFull()
 {
-  RuntimeException::selfThrow("D1MinusLinearOSI::computeResidu_explicit_acceleration_level has been removed due to obsolescence");
+  THROW_EXCEPTION("D1MinusLinearOSI::computeResidu_explicit_acceleration_level has been removed due to obsolescence");
   return 0.0;
 }
