@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -38,7 +38,7 @@
 // #define DEBUG_NOCOLOR
 // #define DEBUG_STDOUT
 // #define DEBUG_MESSAGES
-#include "debug.h"
+#include "siconos_debug.h"
 
 // Constructor from solver id - Uses delegated constructor
 GlobalFrictionContact::GlobalFrictionContact(int dimPb, const int numericsSolverId):
@@ -50,9 +50,9 @@ GlobalFrictionContact::GlobalFrictionContact(int dimPb, const int numericsSolver
 GlobalFrictionContact::GlobalFrictionContact(int dimPb, SP::SolverOptions options):
   LinearOSNS(options), _contactProblemDim(dimPb), _gfc_driver(&gfc3d_driver)
 {
-  // Only fc3d for the moment.
-  if(_contactProblemDim != 3)
-    RuntimeException::selfThrow("GlobalFrictionContact No solver for 2 dimensional problems");
+  // // Only fc3d for the moment.
+  // if(_contactProblemDim != 3)
+  //   THROW_EXCEPTION("GlobalFrictionContact No solver for 2 dimensional problems");
 
   //Reset default storage type for numerics matrices.
   _numericsMatrixStorageType = NM_SPARSE;
@@ -111,7 +111,7 @@ void GlobalFrictionContact::initOSNSMatrix()
     }
     {
       default:
-        RuntimeException::selfThrow("GlobalFrictionContact::initOSNSMatrix unknown _storageType");
+        THROW_EXCEPTION("GlobalFrictionContact::initOSNSMatrix unknown _storageType");
       }
     }
   }
@@ -139,7 +139,7 @@ void GlobalFrictionContact::initOSNSMatrix()
     }
     {
       default:
-        RuntimeException::selfThrow("GlobalFrictionContact::initOSNSMatrix unknown _storageType");
+        THROW_EXCEPTION("GlobalFrictionContact::initOSNSMatrix unknown _storageType");
       }
     }
   }
@@ -201,6 +201,30 @@ GlobalFrictionContactProblem *GlobalFrictionContact::globalFrictionContactProble
 }
 
 
+bool GlobalFrictionContact::checkCompatibleNSLaw(NonSmoothLaw& nslaw)
+{
+
+  float type_number= (float) (Type::value(nslaw) + 0.1 * nslaw.size());
+  _nslawtype.insert(type_number);
+
+  if (Type::value(nslaw) != Type::NewtonImpactFrictionNSL)
+  {
+    THROW_EXCEPTION("\nGlobalFrictionContact::checkCompatibleNSLaw -  \n\
+                      The chosen nonsmooth law is not compatible with FrictionalContact one step nonsmooth problem. \n\
+                      Compatible NonSmoothLaw is NewtonImpactFrictionNSL (3D) \n");
+    return false;
+  }
+  if (_nslawtype.size() > 1)
+  {
+    THROW_EXCEPTION("\nFrictionContact::checkCompatibleNSLaw -  \n\
+                     Compatible NonSmoothLaw is : NewtonImpactFrictionNSL (3D), but you cannot mix them \n");
+    return false;
+  }
+
+  return true;
+}
+
+
 
 bool GlobalFrictionContact::preCompute(double time)
 {
@@ -291,7 +315,7 @@ bool GlobalFrictionContact::preCompute(double time)
       }
       else
       {
-        RuntimeException::selfThrow("GlobalFrictionContact::computeq. Not yet implemented for Integrator type : " + std::to_string(osiType));
+        THROW_EXCEPTION("GlobalFrictionContact::computeq. Not yet implemented for Integrator type : " + std::to_string(osiType));
       }
       offset += dss;
     }
@@ -334,11 +358,12 @@ bool GlobalFrictionContact::preCompute(double time)
       }
       else
       {
-        RuntimeException::selfThrow("GlobalFrictionContact::computeq. Not yet implemented for Integrator type : " + std::to_string(osi1Type));
+        THROW_EXCEPTION("GlobalFrictionContact::computeq. Not yet implemented for Integrator type : " + std::to_string(osi1Type));
       }
       SiconosVector& osnsp_rhs = *(*indexSet.properties(*ui).workVectors)[MoreauJeanGOSI::OSNSP_RHS];
       pos =  indexSet.properties(*ui).absolute_position;
-      setBlock(osnsp_rhs, _b, 3, 0, pos);
+      size_t sizeY = inter->dimension();
+      setBlock(osnsp_rhs, _b, sizeY, 0, pos);
     }
     DEBUG_EXPR(_b->display(););
     // Checks z and w sizes and reset if necessary
@@ -353,7 +378,6 @@ bool GlobalFrictionContact::preCompute(double time)
       _w->resize(_sizeOutput);
       _w->zero();
     }
-
     if(_globalVelocities->size() != _sizeGlobalOutput)
     {
       _globalVelocities->resize(_sizeGlobalOutput);
@@ -374,9 +398,12 @@ int GlobalFrictionContact::compute(double time)
     return info;
   updateMu();
   // --- Call Numerics solver ---
-  info= solve();
-  DEBUG_EXPR(display(););
-  postCompute();
+  if(_sizeGlobalOutput != 0)
+  {
+    info= solve();
+    DEBUG_EXPR(display(););
+    postCompute();
+  }
   return info;
 }
 
@@ -462,7 +489,7 @@ void GlobalFrictionContact::postCompute()
       setBlock(*_globalVelocities, twist, sizeDS, pos, 0);
       DEBUG_EXPR(twist->display(););
     }
-    else RuntimeException::selfThrow("GlobalFrictionContact::postCompute() - not yet implemented for Dynamical system of type: " +  Type::name(ds));
+    else THROW_EXCEPTION("GlobalFrictionContact::postCompute() - not yet implemented for Dynamical system of type: " +  Type::name(ds));
 
   }
 
