@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,6 +21,7 @@
 #include "Simulation.hpp"
 #include "NonSmoothDynamicalSystem.hpp"
 #include "NewtonEulerDS.hpp"
+#include "RotationQuaternion.hpp"
 #include "LagrangianLinearTIDS.hpp"
 #include "LagrangianLinearDiagonalDS.hpp"
 
@@ -37,12 +38,12 @@
 #include "OneStepNSProblem.hpp"
 #include "BlockVector.hpp"
 
-//#define DEBUG_NOCOLOR
+// #define DEBUG_NOCOLOR
 // #define DEBUG_STDOUT
 // #define DEBUG_MESSAGES
 //#define DEBUG_BEGIN_END_ONLY
 //#define DEBUG_WHERE_MESSAGES
-#include <debug.h>
+#include "siconos_debug.h"
 
 
 using namespace RELATION;
@@ -61,7 +62,8 @@ MoreauJeanOSI::MoreauJeanOSI(double theta, double gamma):
   OneStepIntegrator(OSI::MOREAUJEANOSI),
   _constraintActivationThreshold(0.0),
   _useGammaForRelation(false),
-  _explicitNewtonEulerDSOperators(false)
+  _explicitNewtonEulerDSOperators(false),
+  _isWSymmetricDefinitePositive(false)
 {
   _levelMinForOutput= 0;
   _levelMaxForOutput =1;
@@ -253,15 +255,15 @@ void MoreauJeanOSI::initializeIterationMatrixW(double time, SP::SecondOrderDS ds
   // - allocate memory for the matrix W
   // - update its content for the current (initial) state of the dynamical system, depending on its type.
   if(!ds)
-    RuntimeException::selfThrow("MoreauJeanOSI::initializeIterationMatrixW(t,ds) - ds == nullptr");
+    THROW_EXCEPTION("MoreauJeanOSI::initializeIterationMatrixW(t,ds) - ds == nullptr");
 
   if(!(checkOSI(_dynamicalSystemsGraph->descriptor(ds))))
-    RuntimeException::selfThrow("MoreauJeanOSI::initializeIterationMatrixW(t,ds) - ds does not belong to the OSI.");
+    THROW_EXCEPTION("MoreauJeanOSI::initializeIterationMatrixW(t,ds) - ds does not belong to the OSI.");
 
   const DynamicalSystemsGraph::VDescriptor& dsv = _dynamicalSystemsGraph->descriptor(ds);
 
   if(_dynamicalSystemsGraph->properties(dsv).W)
-    RuntimeException::selfThrow("MoreauJeanOSI::initializeIterationMatrixW(t,ds) - W(ds) is already in the map and has been initialized.");
+    THROW_EXCEPTION("MoreauJeanOSI::initializeIterationMatrixW(t,ds) - W(ds) is already in the map and has been initialized.");
 
   double h = _simulation->timeStep();
   Type::Siconos dsType = Type::value(*ds);
@@ -366,7 +368,15 @@ void MoreauJeanOSI::initializeIterationMatrixW(double time, SP::SecondOrderDS ds
       _initializeIterationMatrixWBoundaryConditions(*ds,dsv);
 
   }
-  else RuntimeException::selfThrow("MoreauJeanOSI::initializeIterationMatrixW - not yet implemented for Dynamical system of type : " + Type::name(*ds));
+  else THROW_EXCEPTION("MoreauJeanOSI::initializeIterationMatrixW - not yet implemented for Dynamical system of type : " + Type::name(*ds));
+
+
+  if (isWSymmetricDefinitePositive())
+  {
+    SiconosMatrix& W = *_dynamicalSystemsGraph->properties(dsv).W;
+    W.setIsSymmetric(true);
+    W.setIsPositiveDefinite(true);
+  }
 
   // Remark: W is not LU-factorized nor inversed here.
   // Function PLUForwardBackward will do that if required.
@@ -383,10 +393,10 @@ void MoreauJeanOSI::_initializeIterationMatrixWBoundaryConditions(SecondOrderDS&
   DEBUG_BEGIN("MoreauJeanOSI::initializeIterationMatrixWBoundaryConditions(SP::DynamicalSystem ds)\n");
 
   if(!(checkOSI(dsv)))
-    RuntimeException::selfThrow("MoreauJeanOSI::initializeIterationMatrixWBoundaryConditions(t,ds) - ds does not belong to the OSI.");
+    THROW_EXCEPTION("MoreauJeanOSI::initializeIterationMatrixWBoundaryConditions(t,ds) - ds does not belong to the OSI.");
 
   if(_dynamicalSystemsGraph->properties(dsv).WBoundaryConditions)
-    RuntimeException::selfThrow("MoreauJeanOSI::initializeIterationMatrixWBoundaryConditions(t,ds) - WBoundaryConditions(ds) is already in the map and has been initialized.");
+    THROW_EXCEPTION("MoreauJeanOSI::initializeIterationMatrixWBoundaryConditions(t,ds) - WBoundaryConditions(ds) is already in the map and has been initialized.");
 
 
   Type::Siconos dsType = Type::value(ds);
@@ -401,12 +411,12 @@ void MoreauJeanOSI::_initializeIterationMatrixWBoundaryConditions(SecondOrderDS&
     SP::BoundaryCondition bc = d.boundaryConditions();
 
     unsigned int numberBoundaryConditions = bc->velocityIndices()->size();
-    _dynamicalSystemsGraph->properties(dsv).WBoundaryConditions.reset(new SimpleMatrix(sizeWBoundaryConditions, numberBoundaryConditions));
+    _dynamicalSystemsGraph->properties(dsv).WBoundaryConditions.reset(new SimpleMatrix(sizeWBoundaryConditions, numberBoundaryConditions, d.mass()->num()));
     _computeWBoundaryConditions(ds,*_dynamicalSystemsGraph->properties(dsv).WBoundaryConditions,
                                 *_dynamicalSystemsGraph->properties(dsv).W);
   }
   else
-    RuntimeException::selfThrow("MoreauJeanOSI::initializeIterationMatrixWBoundaryConditions - not yet implemented for Dynamical system of type :" +  Type::name(ds));
+    THROW_EXCEPTION("MoreauJeanOSI::initializeIterationMatrixWBoundaryConditions - not yet implemented for Dynamical system of type :" +  Type::name(ds));
   DEBUG_END("MoreauJeanOSI::initializeIterationMatrixWBoundaryConditions(SP::DynamicalSystem ds) \n");
 }
 
@@ -427,7 +437,7 @@ void MoreauJeanOSI::_computeWBoundaryConditions(SecondOrderDS& ds,
   if(dsType == Type::LagrangianLinearTIDS || dsType == Type::LagrangianDS ||  dsType == Type::NewtonEulerDS || dsType == Type::LagrangianLinearDiagonalDS)
   {
 
-    SP::SiconosVector columntmp(new SiconosVector(ds.dimension()));
+    SP::SiconosVector columntmp(new SiconosVector(ds.dimension(), WBoundaryConditions.num()));
 
     int columnindex = 0;
 
@@ -439,7 +449,7 @@ void MoreauJeanOSI::_computeWBoundaryConditions(SecondOrderDS& ds,
         itindex != bc->velocityIndices()->end();
         ++itindex)
     {
-      if(!iteration_matrix.isSymmetric(1e-10))
+      if(!iteration_matrix.checkSymmetry(1e-10))
       {
         // iteration_matrix.display();
         std::cout <<"Warning, we apply boundary conditions assuming W symmetric" << std::endl;
@@ -460,7 +470,7 @@ void MoreauJeanOSI::_computeWBoundaryConditions(SecondOrderDS& ds,
     DEBUG_EXPR(WBoundaryConditions.display(););
   }
   else
-    RuntimeException::selfThrow("MoreauJeanOSI::computeWBoundaryConditions - not yet implemented for Dynamical system type : " +  Type::name(ds));
+    THROW_EXCEPTION("MoreauJeanOSI::computeWBoundaryConditions - not yet implemented for Dynamical system type : " +  Type::name(ds));
   DEBUG_END("MoreauJeanOSI::_computeWBoundaryConditions\n");
 }
 
@@ -529,10 +539,10 @@ void MoreauJeanOSI::computeW(double t, SecondOrderDS& ds, SiconosMatrix& W)
       //*W -= h*h*_theta*_theta**K;
     }
     DEBUG_EXPR(W.display(););
-    DEBUG_EXPR_WE(std::cout <<  std::boolalpha << "W.isPLUFactorized() = "<< W.isPLUFactorized() << std::endl;);
+    DEBUG_EXPR_WE(std::cout <<  std::boolalpha << "W.isFactorized() = "<< W.isFactorized() << std::endl;);
 
   }
-  else RuntimeException::selfThrow("MoreauJeanOSI::computeW - not yet implemented for Dynamical system of type : " +Type::name(ds));
+  else THROW_EXCEPTION("MoreauJeanOSI::computeW - not yet implemented for Dynamical system of type : " +Type::name(ds));
 
 
   DEBUG_END("MoreauJeanOSI::computeW\n");
@@ -660,6 +670,7 @@ double MoreauJeanOSI::computeResidu()
       const SiconosVector &v = *d.velocity(); // v = v_k,i+1
       //residuFree.zero();
       DEBUG_EXPR(residuFree.display());
+
       DEBUG_EXPR(vold.display());
       DEBUG_EXPR(v.display());
 
@@ -679,6 +690,9 @@ double MoreauJeanOSI::computeResidu()
         scal(coef, fold, residuFree, false);
 
         // Expensive computes forces(ti,vi,qi)
+        // SiconosVector &qold = *d.qMemory()->getSiconosVector(0);
+        // SiconosVector &vold = *d.velocityMemory()->getSiconosVector(0);
+
         // d.computeForces(told, qold, vold);
         // double coef = -h * (1 - _theta);
         // // residuFree += coef * fL_i
@@ -963,7 +977,7 @@ double MoreauJeanOSI::computeResidu()
       DEBUG_PRINTF("normResidu= %e\n", normResidu);
     }
     else
-      RuntimeException::selfThrow("MoreauJeanOSI::computeResidu - not yet implemented for Dynamical system of type: " + Type::name(ds));
+      THROW_EXCEPTION("MoreauJeanOSI::computeResidu - not yet implemented for Dynamical system of type: " + Type::name(ds));
 
     if(normResidu > maxResidu) maxResidu = normResidu;
 
@@ -1063,7 +1077,7 @@ void MoreauJeanOSI::computeFreeState()
       // -- vfree =  v - W^{-1} ResiduFree --
       // At this point vfree = residuFree
       // -> Solve WX = vfree and set vfree = X
-      W.PLUForwardBackwardInPlace(vfree);
+      W.Solve(vfree);
       // -> compute real vfree
       vfree *= -1.0;
       // Get state i (previous time step) from Memories -> var. indexed with "Old"
@@ -1107,7 +1121,7 @@ void MoreauJeanOSI::computeFreeState()
 
     //   vfree = residuFree;
     //   DEBUG_EXPR(vfree.display());
-    //   W.PLUForwardBackwardInPlace(vfree);
+    //   W.Solve(vfree);
     //   vfree *= -1.0;
     //   vfree += vold;
 
@@ -1183,7 +1197,7 @@ void MoreauJeanOSI::computeFreeState()
     //   //    vfree->display();
     //   DEBUG_EXPR(residuFree.display(););
 
-    //   W.PLUForwardBackwardInPlace(vfree);
+    //   W.Solve(vfree);
     //   //    std::cout<<"MoreauJeanOSI::computeFreeState -WRfree"<<endl;
     //   //    vfree->display();
     //   //    scal(h,*vfree,*vfree);
@@ -1194,7 +1208,7 @@ void MoreauJeanOSI::computeFreeState()
     //   DEBUG_EXPR(vfree.display(););
     // }
     // else
-    //   RuntimeException::selfThrow("MoreauJeanOSI::computeFreeState - not yet implemented for Dynamical system of type: " +  Type::name(ds));
+    //   THROW_EXCEPTION("MoreauJeanOSI::computeFreeState - not yet implemented for Dynamical system of type: " +  Type::name(ds));
 
   }
   DEBUG_END("MoreauJeanOSI::computeFreeState()\n");
@@ -1397,7 +1411,7 @@ void MoreauJeanOSI::computeFreeOutput(InteractionsGraph::VDescriptor& vertex_int
       // current Interaction.
       if(_useGammaForRelation)
       {
-        RuntimeException::selfThrow("MoreauJeanOSI::computeFreeOutput Configuration not possible");
+        THROW_EXCEPTION("MoreauJeanOSI::computeFreeOutput Configuration not possible");
 //        subprod(C, *deltax, osnsp_rhs, coord, true);
       }
       else
@@ -1430,7 +1444,7 @@ void MoreauJeanOSI::computeFreeOutput(InteractionsGraph::VDescriptor& vertex_int
           subprod(*ID, *(std::static_pointer_cast<LagrangianRheonomousR>(inter.relation())->hDot()), osnsp_rhs, xcoord, false); // y += hDot
         }
         else
-          RuntimeException::selfThrow("MoreauJeanOSI::computeFreeOutput not yet implemented for SICONOS_OSNSP ");
+          THROW_EXCEPTION("MoreauJeanOSI::computeFreeOutput not yet implemented for SICONOS_OSNSP ");
       }
       if(relationSubType == CompliantLinearTIR)
       {
@@ -1457,7 +1471,7 @@ void MoreauJeanOSI::computeFreeOutput(InteractionsGraph::VDescriptor& vertex_int
           }
         }
         else
-          RuntimeException::selfThrow("MoreauJeanOSI::computeFreeOutput not yet implemented for SICONOS_OSNSP ");
+          THROW_EXCEPTION("MoreauJeanOSI::computeFreeOutput not yet implemented for SICONOS_OSNSP ");
       }
       DEBUG_EXPR(osnsp_rhs.display(););
 
@@ -1550,10 +1564,10 @@ void MoreauJeanOSI::integrate(double& tinit, double& tend, double& tout, int& no
         scal(coeff, *Fext, v, false); // v += h*theta * fext(ti+1)
       }
       // -> Solve WX = v and set v = X
-      W->PLUForwardBackwardInPlace(v);
+      W->Solve(v);
       v += vold;
     }
-    else RuntimeException::selfThrow("MoreauJeanOSI::integrate - not yet implemented for Dynamical system of type :" +  Type::name(*ds));
+    else THROW_EXCEPTION("MoreauJeanOSI::integrate - not yet implemented for Dynamical system of type :" +  Type::name(*ds));
   }
 }
 
@@ -1586,44 +1600,62 @@ void MoreauJeanOSI::updatePosition(DynamicalSystem& ds)
   }
   else if(dsType == Type::NewtonEulerDS)
   {
+
+    // Old Version with projection
+    //  NewtonEulerDS& d = static_cast<NewtonEulerDS&> (ds);
+    // SiconosVector &v = *d.twist();
+    // DEBUG_EXPR(d.display());
+    // //compute q
+    // //first step consists in computing  \dot q.
+    // //second step consists in updating q.
+    // //
+    // SiconosMatrix& T = *d.T();
+    // SiconosVector& dotq = *d.dotq();
+    // DEBUG_EXPR(v.display());
+    // prod(T, v, dotq, true);
+    // DEBUG_EXPR(dotq.display());
+    // SiconosVector& q = *d.q();
+    // //  -> get previous time step state
+    // SiconosVector& dotqold = *d.dotqMemory()->getSiconosVector(0);
+    // DEBUG_EXPR(dotqold.display());
+    // // *q = *qold + h*(theta * *v +(1.0 - theta)* *vold)
+    // double coeff = h * _theta;
+    // scal(coeff, dotq, q) ; // q = h*theta*v
+    // coeff = h * (1 - _theta);
+    // scal(coeff, dotqold, q, false); // q += h(1-theta)*vold
+    // SiconosVector& qold = *d.qMemory()->getSiconosVector(0);
+    // DEBUG_EXPR(qold.display());
+    // q += qold;   // q += qold
+    // DEBUG_PRINT("new q before normalizing\n");
+    // DEBUG_EXPR(q.display());
+    // //q[3:6] must be normalized
+    // d.normalizeq();
+    // DEBUG_PRINT("new q after normalizing\n");
+    // DEBUG_EXPR(q.display());
+
+    
     // get dynamical system
-    NewtonEulerDS& d = static_cast<NewtonEulerDS&>(ds);
-    const SiconosVector &v = *d.twist();
-    //DEBUG_EXPR(d.display());
-
-    //compute q
-    //first step consists in computing  \dot q.
-    //second step consists in updating q.
-    //
-    SiconosMatrix& T = *d.T();
-    SiconosVector& dotq = *d.dotq();
-    DEBUG_EXPR(v.display());
-    prod(T, v, dotq, true);
-    DEBUG_EXPR(dotq.display());
-
-    SiconosVector& q = *d.q();
-    //  -> get previous time step state
-    const SiconosVector& dotqold = d.dotqMemory().getSiconosVector(0);
-    DEBUG_EXPR(dotqold.display());
-
-
-    // *q = *qold + h*(theta * *v +(1.0 - theta)* *vold)
-    double coeff = h * _theta;
-    scal(coeff, dotq, q) ; // q = h*theta*v
-
-    coeff = h * (1 - _theta);
-    scal(coeff, dotqold, q, false); // q += h(1-theta)*vold
+    NewtonEulerDS& d = static_cast<NewtonEulerDS&> (ds);
 
     const SiconosVector& qold = d.qMemory().getSiconosVector(0);
-    DEBUG_EXPR(qold.display());
-    q += qold;   // q += qold
+    const SiconosVector& vold = d.twistMemory().getSiconosVector(0);
+    SiconosVector& q = *d.q();
+    SiconosVector& v = *d.twist();
+
+    SP::SiconosVector velocityIncrement(new SiconosVector(v.size()));
+    double coeff = h * _theta;
+    scal(coeff, v, *velocityIncrement) ; //  velocityIncrement= h*theta*v
+    coeff = h * (1 - _theta);
+    scal(coeff, vold, *velocityIncrement, false); // velocityIncrement += h(1-theta)*vold
+    DEBUG_EXPR(velocityIncrement->display());
+
+    q.setValue(0,velocityIncrement->getValue(0));
+    q.setValue(1,velocityIncrement->getValue(1));
+    q.setValue(2,velocityIncrement->getValue(2));
+    quaternionFromTwistVector(*velocityIncrement, q);
 
-    DEBUG_PRINT("new q before normalizing\n");
     DEBUG_EXPR(q.display());
-
-    //q[3:6] must be normalized
-    d.normalizeq();
-    DEBUG_PRINT("new q after normalizing\n");
+    compositionLawLieGroup(qold, q);
     DEBUG_EXPR(q.display());
 
   }
@@ -1685,7 +1717,7 @@ void MoreauJeanOSI::updateState(const unsigned int)
         }
         else
         {
-          W.PLUForwardBackwardInPlace(v);
+          W.Solve(v);
           v +=  vfree;
         }
       }
@@ -1772,7 +1804,7 @@ void MoreauJeanOSI::updateState(const unsigned int)
               ++itindex)
             v.setValue(*itindex, 0.0);
 
-        _dynamicalSystemsGraph->properties(*dsi).W->PLUForwardBackwardInPlace(v);
+        _dynamicalSystemsGraph->properties(*dsi).W->Solve(v);
 
         DEBUG_EXPR(d.p(_levelMaxForInput)->display());
         DEBUG_PRINT("MoreauJeanOSI::updatestate W CT lambda\n");
@@ -1814,7 +1846,7 @@ void MoreauJeanOSI::updateState(const unsigned int)
       updatePosition(ds);
 
     }
-    else RuntimeException::selfThrow("MoreauJeanOSI::updateState - not yet implemented for Dynamical system of type: " +  Type::name(ds));
+    else THROW_EXCEPTION("MoreauJeanOSI::updateState - not yet implemented for Dynamical system of type: " +  Type::name(ds));
 
   }
   DEBUG_END("MoreauJeanOSI::updateState(const unsigned int)\n");
