@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,11 +20,11 @@
 
 int QP::compute(double)
 {
-  RuntimeException::selfThrow("QP::compute not yet implemented");
+  THROW_EXCEPTION("QP::compute not yet implemented");
   return 1;
 }
 
 void QP::display() const
 {
-  RuntimeException::selfThrow("QP::compute not yet implemented");
+  THROW_EXCEPTION("QP::compute not yet implemented");
 }
