@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -39,7 +39,7 @@
 //#define DEBUG_STDOUT
 //#define DEBUG_MESSAGES
 //#define DEBUG_WHERE_MESSAGES
-#include <debug.h>
+#include "siconos_debug.h"
 
 
 
@@ -59,7 +59,7 @@ TimeSteppingCombinedProjection::TimeSteppingCombinedProjection(
   _indexSetLevelForProjection = level;
   if(_indexSetLevelForProjection != 2)
   {
-    RuntimeException::selfThrow("TimeSteppingCombinedProjection::TimeSteppingCombinedProjection level not equal to 2 is not yet implemented.  ");
+    THROW_EXCEPTION("TimeSteppingCombinedProjection::TimeSteppingCombinedProjection level not equal to 2 is not yet implemented.  ");
 
   }
   _constraintTol = 1e-08;
@@ -305,7 +305,7 @@ void TimeSteppingCombinedProjection::advanceToEvent()
 
     if(_nbIndexSetsIteration > _kIndexSetMax)
     {
-      RuntimeException::selfThrow("TimeSteppingCombinedProjection::TimeSteppingCombinedProjection _nbIndexSetsIteration >  _kIndexSetMax ");
+      THROW_EXCEPTION("TimeSteppingCombinedProjection::TimeSteppingCombinedProjection _nbIndexSetsIteration >  _kIndexSetMax ");
     }
 
 
@@ -424,7 +424,7 @@ void TimeSteppingCombinedProjection::advanceToEvent()
         *workVectors[MoreauJeanOSI::QTMP] = * d->q();
       }
       else
-        RuntimeException::selfThrow("TimeSteppingCombinedProjection::advanceToEvent() :: - Ds is not from NewtonEulerDS neither from LagrangianDS.");
+        THROW_EXCEPTION("TimeSteppingCombinedProjection::advanceToEvent() :: - Ds is not from NewtonEulerDS neither from LagrangianDS.");
     }
 
 
@@ -518,7 +518,7 @@ void TimeSteppingCombinedProjection::advanceToEvent()
 #endif
         }
         else
-          RuntimeException::selfThrow("TimeSteppingCombinedProjection::advanceToEvent() - Ds is not from NewtonEulerDS neither from LagrangianDS.");
+          THROW_EXCEPTION("TimeSteppingCombinedProjection::advanceToEvent() - Ds is not from NewtonEulerDS neither from LagrangianDS.");
 
       }
 
@@ -595,7 +595,7 @@ void TimeSteppingCombinedProjection::advanceToEvent()
       {
       }
       else
-        RuntimeException::selfThrow("TimeSteppingCombinedProjection::advanceToEvent() - Ds is not from NewtonEulerDS neither from LagrangianDS.");
+        THROW_EXCEPTION("TimeSteppingCombinedProjection::advanceToEvent() - Ds is not from NewtonEulerDS neither from LagrangianDS.");
     }
 
 
