@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,7 +19,8 @@
 #define ALGEBRATOOLS_HPP
 
 /*! \file AlgebraTools.hpp
-  Utilities to perform operations on matrices (exponantial ...)
+  Utilities to perform operations on matrices
+ (exponential ...)
 */
 
 #include "SiconosFwd.hpp"
@@ -36,7 +37,7 @@ namespace Siconos {
     \param computeAndAdd : if true, result = result + exp(A)
 **/
       void expm(SiconosMatrix& A, SiconosMatrix& Exp, bool computeAndAdd = false);
-    
+
     } // namespace tools
   } // namespace algebra
 } // namespace Siconos
