@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,10 +27,8 @@
 #include <stddef.h>                    // for size_t
 #include <iosfwd>                      // for ostream
 #include "CSparseMatrix.h"             // for CSparseMatrix
-#include "RuntimeException.hpp"        // for RuntimeException
 #include "SiconosAlgebraTypeDef.hpp"   // for DenseMat, BandedMat, IdentityMat
 #include "SiconosFwd.hpp"              // for SiconosMatrix
-#include "SiconosMatrixException.hpp"  // for SiconosMatrixException
 #include "SiconosSerialization.hpp"    // for ACCEPT_SERIALIZATION
 #include "SiconosVisitor.hpp"          // for VIRTUAL_ACCEPT_VISITORS
 class BlockVector;
@@ -74,7 +72,17 @@ protected:
   /** A number to specify the type of the matrix: (block or ublas-type)
    * 0-> BlockMatrix, 1 -> DenseMat, 2 -> TriangMat, 3 -> SymMat, 4->SparseMat, 5->BandedMat, 6->zeroMat, 7->IdentityMat
    */
-  unsigned int _num;
+  Siconos::UBLAS_TYPE _num;
+
+  /** bool _isSymmetric;
+   *  Boolean = true if the Matrix is symmetric
+   */
+  bool _isSymmetric;
+
+  /** bool _isPositiveDefinite;
+   *  Boolean = true if the Matrix is positive definite
+   */
+  bool _isPositiveDefinite;
 
   /** default constructor */
   SiconosMatrix() {};
@@ -82,29 +90,29 @@ protected:
   /** basic constructor
    *   \param type unsigned int type-number of the vector
    */
-  SiconosMatrix(unsigned int type);
+  SiconosMatrix(Siconos::UBLAS_TYPE type);
 
   /**  computes y = subA*x (init =true) or += subA * x (init = false), subA being a submatrix of A (all columns, and rows between start and start+sizeY).
    *  If x is a block vector, it call the present function for all blocks.
-   * \param A a pointer to SiconosMatrix 
+   * \param A a pointer to SiconosMatrix
    * \param startRow an int, sub-block position
    * \param x a pointer to a SiconosVector
    * \param y a pointer to a SiconosVector
    * \param init a bool
    */
   void private_prod(unsigned int startRow, const SiconosVector& x, SiconosVector& y, bool init) const;
-  
-  
+
+
   /**  computes res = subA*x +res, subA being a submatrix of A (rows from startRow to startRow+sizeY and columns between startCol and startCol+sizeX).
    * If x is a block vector, it call the present function for all blocks.
-   * \param A a pointer to SiconosMatrix 
+   * \param A a pointer to SiconosMatrix
    * \param startRow an int, sub-block position
    * \param startCol an int, sub-block position
    * \param x a pointer to a SiconosVector
    * \param res a DenseVect
    */
   void private_addprod(unsigned int startRow, unsigned int startCol, const SiconosVector& x, SiconosVector& res) const;
-  
+
 public:
 
   /** Destructor. */
@@ -114,7 +122,7 @@ public:
    * \return a bool.*/
   inline bool isBlock(void) const
   {
-    if (_num == 0) return true ;
+    if (_num == Siconos::BLOCK) return true ;
     else return false;
   }
 
@@ -126,12 +134,40 @@ public:
     return false;
   };
 
+  /** true if the matrix is symmetric (the flag is just returned)
+   *  \return true if the matrix is symmetric
+   */
+  inline bool isSymmetric() const
+  {
+    return _isSymmetric;
+  }
+
+  /** set the flag _isSymmetric */
+  inline void setIsSymmetric(bool b)
+  {
+    _isSymmetric= b;
+  }
+
+  /** true if the matrix is definite positive (the flag is just returned)
+   *  \return true if the matrix is
+   */
+  inline bool isPositiveDefinite() const
+  {
+    return _isPositiveDefinite;
+  }
+
+  /** set the flag _isPositiveDefinite */
+  inline void setIsPositiveDefinite(bool b)
+  {
+    _isPositiveDefinite= b ;
+  }
+
   /** determines if the matrix is symmetric up to a given tolerance
    *  \return true if the matrix is inversed
    */
-  virtual bool isSymmetric(double tol) const =0;
+  virtual bool checkSymmetry(double tol) const =0;
 
-  /** determines if the matrix has been PLU factorized in place
+  /** determines if the matrix has been PLU factorized
    *  \return true if the matrix is factorized
    */
   inline virtual bool isPLUFactorized() const
@@ -139,6 +175,21 @@ public:
     return false;
   };
 
+  /** determines if the matrix has been PLU factorized in place
+   *  \return true if the matrix is factorized
+   */
+  inline virtual bool isPLUFactorizedInPlace() const
+  {
+    return false;
+  };
+
+  /** determines if the matrix has been Cholesky factorized
+   *  \return true if the matrix is factorized
+   */
+  inline virtual bool isCholeskyFactorized() const
+  {
+    return false;
+  };
 
   /** determines if the matrix has been QR factorized
    *  \return true if the matrix is factorized
@@ -154,6 +205,15 @@ public:
     return dummy;
   }
 
+  /** determines if the matrix has been factorized
+   *  \return true if the matrix is factorized
+   */
+  inline virtual bool isFactorized() const
+  {
+    return (isPLUFactorized() || isPLUFactorizedInPlace() || isCholeskyFactorized() || isQRFactorized());
+  };
+
+
   /** get the number of rows or columns of the matrix
    *  \param index 0 for rows, 1 for columns
    *  \return an int
@@ -163,7 +223,7 @@ public:
   /** get the attribute num of current matrix
    * \return an unsigned int.
    */
-  inline unsigned int num() const
+  inline Siconos::UBLAS_TYPE num() const
   {
     return _num;
   };
@@ -277,7 +337,7 @@ public:
    *  \return a SparseMat*
    */
   virtual SparseMat* sparse(unsigned int row = 0, unsigned int col = 0) const = 0;
-  
+
   /** get a pointer on SparseCoordinateMat matrix
    *  \param row an unsigned int, position of the block (row) - Useless for SimpleMatrix
    *  \param col an unsigned int, position of the block (column) - Useless for SimpleMatrix
@@ -299,7 +359,7 @@ public:
    */
   virtual IdentityMat* identity(unsigned int row = 0, unsigned int col = 0) const = 0;
 
-  /** return the address of the array of double values of the matrix 
+  /** return the address of the array of double values of the matrix
    *   ( for block(i,j) if this is a block matrix)
    *  \param row position for the required block
    *  \param col position for the required block
@@ -316,7 +376,7 @@ public:
   virtual void randomize() = 0;
 
   /** Initialize a symmetric matrix with random values
-   */ 
+   */
   virtual void randomize_sym()= 0;
 
   /** set an identity matrix
@@ -341,7 +401,7 @@ public:
   /** display data on standard output
    */
   virtual void display() const = 0;
-  
+
   /** display data on standard output
    */
   virtual void displayExpert(bool brief = true ) const = 0;
@@ -390,10 +450,9 @@ public:
    */
   virtual SP::SiconosMatrix block(unsigned int row = 0, unsigned int col = 0)
   {
-    RuntimeException::selfThrow("SP::SiconosMatrix block(...) must be implemented");
-    return SP::SiconosMatrix();
+    THROW_EXCEPTION("must be implemented");
   };
-  
+
 
   /** get block at position row-col if BlockMatrix, else if SimpleMatrix return this
    *  \param row unsigned int row
@@ -402,8 +461,7 @@ public:
    */
   virtual SPC::SiconosMatrix block(unsigned int row = 0, unsigned int col = 0) const
   {
-    RuntimeException::selfThrow("SP::SiconosMatrix block(...) must be implemented");
-    return SPC::SiconosMatrix();
+    THROW_EXCEPTION("must be implemented");
   };
 
   /** get row index of current matrix and save it into vOut
@@ -463,36 +521,84 @@ public:
    */
   virtual SiconosMatrix& operator -=(const SiconosMatrix& m) = 0;
 
-  /** computes a LU factorization of a general M-by-N matrix using partial pivoting with row interchanges.
-   *  The result is returned in this (InPlace). Based on Blas dgetrf function.
+
+  virtual void updateNumericsMatrix() =0;
+
+  virtual NumericsMatrix * numericsMatrix() const
+  {
+    return nullptr;
+  };
+
+  
+  /** computes a LU factorization of a general M-by-N matrix
+   * with partial pivoting and row interchanges.
+   * The result is returned in this (InPlace).
+   * Based on Blas dgetrf function for dense matrix and
+   * ublas cholesky decomposition for sparse matrix
+   * (work only for a symmetric matrix and very slow because it uses
+   * matric accessor)
+   * use preferably PLUFactorize()
    */
   virtual void PLUFactorizationInPlace() = 0;
 
-  /**  compute inverse of this thanks to LU factorization with Partial pivoting. This method inverts U and then computes inv(A) by solving the system
-   *  inv(A)*L = inv(U) for inv(A). The result is returned in this (InPlace). Based on Blas dgetri function.
+  /** computes a factorization of a general M-by-N matrix
+   * The implementation is based on an internal NumericsMatrix
+   */
+  virtual void Factorize() = 0;
+
+  /**  compute inverse of this thanks to LU factorization with partial pivoting.
+   * This method inverts U and then computes inv(A) by solving the system
+   * inv(A)*L = inv(U) for inv(A).
+   * The result is returned in this (InPlace).
+   * Based on Blas dgetri function for dense function
    */
   virtual void  PLUInverseInPlace() = 0;
 
-  /** solves a system of linear equations A * X = B  (A=this) with a general N-by-N matrix A using the LU factorization computed
-   *   by PLUFactorizationInPlace. Based on Blas dgetrs function.
-   *  \param[in,out] B on input the RHS matrix b; on output the result x
+  /** solves a system of linear equations A * X = B  (A=this)
+   * for a general N-by-N matrix A using the LU factorization computed
+   * by PLUFactorizationInPlace.
+   * Based on Blas dgetrs function for dense matrix.
+   * \param[in,out] B on input the RHS matrix b; on output the result x
    */
   virtual void  PLUForwardBackwardInPlace(SiconosMatrix &B) = 0;
 
-  /** solves a system of linear equations A * X = B  (A=this) with a general N-by-N matrix A using the LU factorization computed
-   *   by PLUFactorizationInPlace.  Based on Blas dgetrs function.
+  /** solves a system of linear equations A * X = B  (A=this)
+   * for a general N-by-N matrix A using the LU factorization computed
+   * by PLUFactorize.
    *  \param[in,out] B on input the RHS matrix b; on output the result x
    */
+  virtual void  Solve(SiconosMatrix &B) = 0;
+
+  /** solves a system of linear equations A * X = B  (A=this)
+   * for a general N-by-N matrix A using the LU factorization computed
+   * by PLUFactorizationInPlace.
+   * Based on Blas dgetrs function for dense matrix.
+   * \param[in,out] B on input the RHS matrix b; on output the result x
+   */
   virtual void   PLUForwardBackwardInPlace(SiconosVector &B) = 0;
 
+   /** solves a system of linear equations A * X = B  (A=this)
+   * for a general N-by-N matrix A using the LU factorization computed
+   * by PLUFactorize.
+   *  \param[in,out] B on input the RHS matrix b; on output the result x
+   */
+  virtual void   Solve(SiconosVector &B) = 0;
+
   /** set to false all LU indicators. Useful in case of
       assignment for example.
   */
   virtual void resetLU()
   {
-    SiconosMatrixException::selfThrow(" SiconosMatrix::resetLU not yet implemented for BlockMatrix.");
+    THROW_EXCEPTION(" SiconosMatrix::resetLU not yet implemented for BlockMatrix.");
   };
 
+  /** set to false all factorization indicators. Useful in case of
+      assignment for example.
+  */
+  virtual void resetFactorizationFlags()
+  {
+    THROW_EXCEPTION(" SiconosMatrix::resetFactorizationFlags not yet implemented for BlockMatrix.");
+  };
 
   /** return the number of non-zero in the matrix
    * \param tol the tolerance to consider a number zero (not used if the matrix is sparse)
@@ -500,15 +606,25 @@ public:
    */
   virtual size_t nnz(double tol = 1e-14);
 
-  /** Fill sparse matrix
+  /** Fill CSparseMatrix compresses column sparse matrix
    *  \param csc the compressed column sparse matrix
    *  \param row_off
    *  \param col_off
-   *  \param tol the tolerance under which a number is considered as equal to zero 
+   *  \param tol the tolerance under which a number is considered as equal to zero
    *  \return true if function worked.
+   *  \warning not clear that it works for an empty csr matrix with row_off =0  and col_off =0
    */
   bool fillCSC(CSparseMatrix* csc, size_t row_off, size_t col_off, double tol = 1e-14);
 
+  /** Fill CSparseMatrix compresses column sparse matrix
+   *  \param csc the compressed column sparse matrix
+   *  \param tol the tolerance under which a number is considered as equal to zero
+   *  \return true if function worked.
+   */
+  bool fillCSC(CSparseMatrix* csc, double tol = 1e-14);
+
+  bool fromCSC(CSparseMatrix* csc);
+  
   /** return the number of non-zero in the matrix
    *  \param csc the compressed column sparse matrix
    *  \param row_off
@@ -521,11 +637,11 @@ public:
   /** Visitors hook
    */
   VIRTUAL_ACCEPT_VISITORS(SiconosMatrix);
-  
+
   /** \defgroup SiconosMatrixFriends
-      
+
       List of friend functions of the SimpleMatrix class
-      
+
       Declared in SimpleMatrixFriends.hpp.
       Implemented in SimpleMatrixFriends.cpp.
 
