@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,15 +29,21 @@
 #include "SiconosFwd.hpp"             // for SiconosVector, SiconosMatrix
 #include "SiconosMatrix.hpp"          // for SiconosMatrix, VInt, MATRIX_UBL...
 #include "SiconosVector.hpp"          // for SiconosVector
+
+
+
+
+
+
 class BlockVector;
 
 /**  Matrix (embedded various types of Boost matrices of double)
  *
  * SimpleMatrix is used in the platform to store matrices (mathematical object) of double.
  *
- * Possible types: Siconos::DENSE (default), 
+ * Possible types: Siconos::DENSE (default),
  *                          TRIANGULAR, SYMMETRIC, SPARSE, BANDED, ZERO,
- *                          Siconos::IDENTITY, 
+ *                          Siconos::IDENTITY,
  *                          Siconos::SPARSE_COORDINATE.
  *
  * \todo: review resize function for Banded, Symetric and Triangular. Error in tests.
@@ -68,24 +74,35 @@ private:
    */
   SP::VInt _ipiv;
 
-  /** bool _isPLUFactorized;
-   *  Boolean = true if the Matrix has been PLU Factorized in place.
-   */
-  bool _isPLUFactorized;
+  /** True if the Matrix is PLU Factorized. */
+  bool _isPLUFactorized = false;
 
-  /** bool _isQRFactorized;
-   *  Boolean = true if the Matrix has been QR Factorized in place.
-   */
-  bool _isQRFactorized;
+  /** True if the Matrix is PLU Factorized in place.*/
+  bool _isPLUFactorizedInPlace = false;
 
-  /** bool _isPLUInversed;
-   *  Boolean = true if the Matrix has been Inversed in Place
+  /** True if the Matrix is Cholesky Factorized. */
+  bool _isCholeskyFactorized = false;
+
+  /** True if the Matrix is Cholesky Factorized in place. */
+  bool _isCholeskyFactorizedInPlace = false;
+
+  /** True if the Matrix has been QR Factorized in place. */
+  bool _isQRFactorized = false;
+
+  /** True if the Matrix has been Inversed in Place. */
+  bool _isPLUInversed = false;
+
+  /** Numerics Matrix structure
+   * This matrix is used to perform  computation using Numerics,
+   * for instance, the LU factorization of a sparse matrix.
+   * It may contains copy or pointer on the SimpleMatrix.
    */
-  bool _isPLUInversed;
+  SP::NumericsMatrix _numericsMatrix;
+
 
   /**  computes res = subA*x +res, subA being a submatrix of A (rows from startRow to startRow+sizeY and columns between startCol and startCol+sizeX).
    * If x is a block vector, it call the present function for all blocks.
-   * \param A a pointer to SiconosMatrix 
+   * \param A a pointer to SiconosMatrix
    * \param startRow an int, sub-block position
    * \param startCol an int, sub-block position
    * \param x a pointer to a SiconosVector
@@ -93,7 +110,7 @@ private:
    */
   // friend void private_addprod(const SiconosMatrix& A, unsigned int startRow, unsigned int startCol, const SiconosVector& x, SiconosVector& res);
 
- 
+
   /**  computes res = subA*x +res, subA being a submatrix of trans(A) (rows from startRow to startRow+sizeY and columns between startCol and startCol+sizeX).
    *  If x is a block vector, it call the present function for all blocks.
    * \param x a pointer to a SiconosVector
@@ -108,18 +125,18 @@ private:
 
   /**  computes y = subA*x (init =true) or += subA * x (init = false), subA being a submatrix of A (all columns, and rows between start and start+sizeY).
    *  If x is a block vector, it call the present function for all blocks.
-   * \param A a pointer to SiconosMatrix 
+   * \param A a pointer to SiconosMatrix
    * \param startRow an int, sub-block position
    * \param x a pointer to a SiconosVector
    * \param y a pointer to a SiconosVector
    * \param init a bool
    */
   void private_prod(unsigned int startRow, const SiconosVector& x, SiconosVector& y, bool init);
-  
-  
+
+
   /**  computes res = subA*x +res, subA being a submatrix of A (rows from startRow to startRow+sizeY and columns between startCol and startCol+sizeX).
    * If x is a block vector, it call the present function for all blocks.
-   * \param A a pointer to SiconosMatrix 
+   * \param A a pointer to SiconosMatrix
    * \param startRow an int, sub-block position
    * \param startCol an int, sub-block position
    * \param x a pointer to a SiconosVector
@@ -156,7 +173,7 @@ private:
   /**  computes y = subA*x (init =true) or += subA * x (init = false), subA being a submatrix of trans(A) (all columns, and rows between start and start+sizeY).
    *    If x is a block vector, it call the present function for all blocks.
    *    \param x a pointer to a SiconosVector
-   *    \param A a pointer to SiconosMatrix 
+   *    \param A a pointer to SiconosMatrix
    *    \param start an int, sub-block position
    *    \param y a pointer to a SiconosVector
    *    \param init a bool
@@ -167,10 +184,8 @@ private:
   // friend void private_prod(SPC::SiconosVector, SPC::SiconosMatrix, unsigned int, SP::BlockVector, bool);
 
 public:
-  /** Default constructor
-   */
+  /** Default constructor */
   SimpleMatrix();
-  SimpleMatrix(int i);
 
   /** constructor with the type and the dimension of the Boost matrix
    *  \param row number of rows.
@@ -197,7 +212,7 @@ public:
    *  \param smat the matrix to copy
    */
   SimpleMatrix(const SimpleMatrix& smat);
-  
+
   /** copy constructor of a block given by the coord = [r0A r1A c0A c1A]
    *  \param A the matrix which contains the block to extract
    *  \param coord positions of the block to be extracted (row:start, row:end, col:start, col:end)
@@ -233,12 +248,12 @@ public:
    *  \param m a SparseMat
    */
   SimpleMatrix(const SparseMat& m);
-  
+
   /** constructor with a SparseCoordinateMat matrix (see SiconosMatrix.h for details)
    *  \param m a SparseMat
    */
   SimpleMatrix(const SparseCoordinateMat& m);
-  
+
   /** constructor with a ZeroMat matrix (see SiconosMatrix.h for details)
    *  \param m a ZeroMat
    */
@@ -260,6 +275,13 @@ public:
   ~SimpleMatrix();
   //************************** GETTERS/SETTERS  **************************
 
+  void updateNumericsMatrix();
+
+  NumericsMatrix * numericsMatrix() const
+  {
+    return _numericsMatrix.get();
+  };
+
   /** determines if the matrix has been inversed
    *  \return true if the matrix is inversed
    */
@@ -276,6 +298,29 @@ public:
     return _isPLUFactorized;
   }
 
+ /** determines if the matrix has been factorized
+   *  \return true if the matrix is factorized
+   */
+  inline bool isPLUFactorizedInPlace() const
+  {
+    return _isPLUFactorizedInPlace;
+  }
+  /** determines if the matrix has been factorized
+   *  \return true if the matrix is factorized
+   */
+  inline bool isCholeskyFactorized() const
+  {
+    return _isCholeskyFactorized;
+  }
+
+ /** determines if the matrix has been factorized
+   *  \return true if the matrix is factorized
+   */
+  inline bool isCholeskyFactorizedInPlace() const
+  {
+    return _isCholeskyFactorizedInPlace;
+  }
+
   /** determines if the matrix has been factorized
    *  \return true if the matrix is factorized
    */
@@ -284,13 +329,14 @@ public:
     return _isQRFactorized;
   }
 
+
   inline SP::VInt ipiv() const
   {
     return _ipiv;
   }
 
 
-  bool isSymmetric(double tol) const;
+  bool checkSymmetry(double tol) const;
 
   /** get DenseMat matrix
    *  \param row an unsigned int, position of the block - Useless for SimpleMatrix
@@ -326,7 +372,7 @@ public:
    *  \return a SparseMat
    */
   const SparseMat getSparse(unsigned int row = 0, unsigned int col = 0) const;
-  
+
   /** get SparseCoordinateMat matrix
    *  \param row an unsigned int, position of the block - Useless for SimpleMatrix
    *  \param col an unsigned int, position of the block - Useless for SimpleMatrix
@@ -382,7 +428,7 @@ public:
    *  \return a SparseMat*
    */
   SparseMat* sparse(unsigned int row = 0, unsigned int col = 0) const;
-  
+
   /** get a pointer on SparseCoordinateMat matrix
    *  \param row an unsigned int, position of the block - Useless for SimpleMatrix
    *  \param col an unsigned int, position of the block - Useless for SimpleMatrix
@@ -436,7 +482,7 @@ public:
 
   void assign(const SimpleMatrix &smat);
 
-  
+
   /** get the number of rows or columns of the matrix
    *  \param index 0 for rows, 1 for columns
    *  \return the size
@@ -470,7 +516,7 @@ public:
   /** display data on standard output
    */
   void display() const;
-  
+
   void displayExpert(bool  brief = true) const;
   /** put data of the matrix into a std::string
    * \return std::string
@@ -478,43 +524,41 @@ public:
   std::string toString() const;
 
   /** get or set the element matrix[i,j]
-   *  \param i an unsigned int 
-   *  \param j an unsigned int 
-   *  \exception SiconosMatrixException
+   *  \param i an unsigned int
+   *  \param j an unsigned int
    *  \return the element matrix[i,j]
    */
   double& operator()(unsigned int i, unsigned int j);
 
   /** get or set the element matrix[i,j]
-   *  \param i an unsigned int 
-   *  \param j an unsigned int 
-   *  \exception SiconosMatrixException
+   *  \param i an unsigned int
+   *  \param j an unsigned int
    *  \return the element matrix[i,j]
    */
   double operator()(unsigned int i, unsigned int j) const;
 
   /** return the element matrix[i,j]
-   *  \param i an unsigned int 
-   *  \param j an unsigned int 
+   *  \param i an unsigned int
+   *  \param j an unsigned int
    *  \return a double
    */
   double getValue(unsigned int i, unsigned int j) const;
 
   /** set the element matrix[i,j]
-   *  \param i an unsigned int 
-   *  \param j an unsigned int 
+   *  \param i an unsigned int
+   *  \param j an unsigned int
    *  \param value
    */
   void setValue(unsigned int i, unsigned int j, double value);
 
-  /** Copy of the content of a given matrix into the current object, 
+  /** Copy of the content of a given matrix into the current object,
       at position (posRow, posCol).
 
       Defined in SimpleMatrixSetGet.cpp.
-      
+
       \param posRow row-index of the targeted block
       \param posCol col-index of the targeted block
-      \param m source matrix to be copied. Can be a SimpleMatrix or a BlockMatrix.    
+      \param m source matrix to be copied. Can be a SimpleMatrix or a BlockMatrix.
   */
   void setBlock(unsigned int posRow, unsigned int posCol, const SiconosMatrix& m);
 
@@ -593,15 +637,15 @@ public:
   void setSubRow(unsigned int index, unsigned int pos, SP::SiconosVector vIn);
 
   /** add the input matrix to the elements starting from position i (row) and j (col).
-   *  \param i an unsigned int 
-   *  \param j an unsigned int 
+   *  \param i an unsigned int
+   *  \param j an unsigned int
    *  \param m a SiconosMatrix
    */
   void addBlock(unsigned int i, unsigned int j, const SiconosMatrix& m);
 
   /** subtract the input matrix to the elements starting from position i (row) and j (col).
-   *  \param i an unsigned int 
-   *  \param j an unsigned int 
+   *  \param i an unsigned int
+   *  \param j an unsigned int
    *  \param m a SiconosMatrix
    */
   void subBlock(unsigned int i, unsigned int j, const SiconosMatrix& m);
@@ -650,6 +694,10 @@ public:
    */
   void PLUFactorizationInPlace();
 
+  /** computes a factorization of a general M-by-N matrix
+   */
+  void Factorize();
+
   /**  compute inverse of this thanks to LU factorization with Partial pivoting.
    * This method inverts U and then computes inv(A) by solving the system
    *  inv(A)*L = inv(U) for inv(A). The result is returned in this (InPlace). Based on Blas dgetri function.
@@ -661,12 +709,14 @@ public:
    *  \param[in,out] B on input the RHS matrix b; on output the result x
    */
   void PLUForwardBackwardInPlace(SiconosMatrix& B);
+  void Solve(SiconosMatrix& B);
 
   /** solves a system of linear equations A * X = B  (A=this) with a general N-by-N matrix A using the LU factorization computed
    *   by PLUFactorizationInPlace.  Based on Blas dgetrs function.
    *  \param[in,out] B on input the RHS matrix b; on output the result x
    */
   void PLUForwardBackwardInPlace(SiconosVector& B);
+  void Solve(SiconosVector& B);
 
   /** solves a system of linear equations A * X = B  (A=this)
       with a general N-by-N matrix A using the Least squares method
@@ -686,16 +736,29 @@ public:
 
   void resetLU();
 
+  /** set to false all Cholesky indicators. Useful in case of
+      assignment for example.
+  */
+
+  void resetCholesky();
+
   /** set to false all QR indicators. Useful in case of
       assignment for example.
   */
   void resetQR();
 
+  /** set to false all factorization indicators. Useful in case of
+      assignment for example.
+  */
+  void resetFactorizationFlags();
+
+
+
   /** Visitors hook
    */
   ACCEPT_STD_VISITORS();
     /** \defgroup SimpleMatrixFriends
-      
+
       List of friend functions of the SimpleMatrix class
 
       Declared in SimpleMatrixFriends.hpp.
@@ -760,10 +823,9 @@ public:
   /** End of Friend functions group @} */
 
 
-  
+
 };
 
 
 
 #endif
-
