@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,9 +27,7 @@
 #include "ioMatrix.hpp"
 #include "ioVector.hpp"
 
-#include "RuntimeException.hpp"
-#include "SiconosMatrixException.hpp"
-#include "SiconosVectorException.hpp"
+#include "SiconosException.hpp"
 
 #include "SiconosMemory.hpp"
 
