@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -28,7 +28,7 @@
 // #define DEBUG_NOCOLOR
 // #define DEBUG_STDOUT
 // #define DEBUG_MESSAGES
-#include <debug.h>
+#include "siconos_debug.h"
 
 #include <algorithm>
 #include <MechanicsFwd.hpp>
@@ -220,6 +220,7 @@ SiconosBulletOptions::SiconosBulletOptions()
   , minimumPointsPerturbationThreshold(3)
   , enableSatConvex(false)
   , enablePolyhedralContactClipping(false)
+  , Depth2D(0.04)
 {
 }
 
@@ -425,7 +426,7 @@ protected:
 
   SiconosBulletOptions &_options;
 
-  std::vector<SP::btCollisionObject> _queuedCollisionObjects;
+  std::vector<std::pair<SP::btCollisionObject,int>> _queuedCollisionObjects;
 
 public:
   SiconosBulletCollisionManager_impl(SiconosBulletOptions &op) : _options(op) {}
@@ -460,17 +461,74 @@ SiconosBulletCollisionManager::insertStaticContactorSet(
 
 bool SiconosBulletCollisionManager::removeStaticContactorSet(StaticContactorSetID id)
 {
+  DEBUG_BEGIN("bool SiconosBulletCollisionManager::removeStaticContactorSet(StaticContactorSetID id)");
   StaticContactorSetRecord *recptr = static_cast<StaticContactorSetRecord *>(id);
   if(_impl->_staticContactorSetRecords.find(recptr)
-      == _impl->_staticContactorSetRecords.end())
+     == _impl->_staticContactorSetRecords.end())
     return false;
 
   SP::StaticContactorSetRecord rec(_impl->_staticContactorSetRecords[recptr]);
+  // get contactorSet in the contactor set record
+  SP::SiconosContactorSet cs  = rec->contactorSet;
+
+  // Loop over contactors in the contactor set
+  std::vector< SP::SiconosContactor >::const_iterator it;
+  for(it=cs->begin(); it!=cs->end(); it++)
+  {
+    // get the SiconosContactor
+    SP::SiconosContactor sc = (*it);
+
+    // find record associated with static objects in BodyShapeMap related to the
+    // specific ds marked as nullptr
+    BodyShapeMap::iterator itbs(_impl->bodyShapeMap.find(nullptr));
+    for (itbs = _impl->bodyShapeMap.begin(); itbs != _impl->bodyShapeMap.end(); itbs++ )
+    {
+      // Loop over the Body Shape Record and find if a contactor corresponds to the contactor sc
+      std::vector<std::shared_ptr<BodyShapeRecord> >::iterator it2;
+      for(it2 = itbs->second.begin(); it2 != itbs->second.end(); it2++)
+      {
+        if ((*it2)->contactor == sc)
+        {
+          DEBUG_PRINT("Remove Collision Object");
+          _impl->_collisionWorld->removeCollisionObject(&*((*it2)->btobject));
+        }
+      }
+    }
+  }
+
+  // remove from the map of ContactorSetRecords
+  _impl->_staticContactorSetRecords.erase(&*rec);
+
+  DEBUG_END("bool SiconosBulletCollisionManager::removeStaticContactorSet(StaticContactorSetID id)");
   // TODO
-  assert(0 && "removeStaticContactorSet not implemented.");
+  //assert(0 && "removeStaticContactorSet not implemented.");
   return false;
 }
 
+/* We derive a specific callback for filtering the broadphase of Bullet
+ * based on collision group */
+struct SiconosBulletFilterCallback : public btOverlapFilterCallback
+{
+  InteractionManager * _interactionManager;
+
+// return true when pairs need collision
+  virtual bool needBroadphaseCollision(btBroadphaseProxy* proxy0,btBroadphaseProxy* proxy1) const
+  {
+    DEBUG_BEGIN("SiconosBulletFilterCallback :: needBroadphaseCollision\n");
+
+    /* standard filter in Bullet */
+    // bool collides = (proxy0->m_collisionFilterGroup & proxy1->m_collisionFilterMask) != 0;
+    // collides = collides && (proxy1->m_collisionFilterGroup & proxy0->m_collisionFilterMask);
+
+    //add some additional logic here that modified 'collides'
+    SP::NonSmoothLaw nslaw = _interactionManager->nonSmoothLaw(proxy0->m_collisionFilterGroup,proxy1->m_collisionFilterGroup);
+    bool collides = (bool)nslaw;
+
+    DEBUG_END("SiconosBulletFilterCallback :: needBroadphaseCollision\n");
+    return collides;
+  }
+};
+
 void SiconosBulletCollisionManager::initialize_impl()
 {
   _impl.reset(new SiconosBulletCollisionManager_impl(_options));
@@ -505,6 +563,10 @@ void SiconosBulletCollisionManager::initialize_impl()
                          &*_impl->_collisionConfiguration));
 
 
+  btOverlapFilterCallback * filterCallback = new SiconosBulletFilterCallback();
+  reinterpret_cast<SiconosBulletFilterCallback*>(filterCallback)->_interactionManager = this;
+  _impl->_collisionWorld->getPairCache()->setOverlapFilterCallback(filterCallback);
+
   DEBUG_PRINTF("_options.dimension = %i", _options.dimension);
 
   //2D specific
@@ -539,6 +601,8 @@ SiconosBulletCollisionManager::SiconosBulletCollisionManager()
   initialize_impl();
 }
 
+
+
 SiconosBulletCollisionManager::SiconosBulletCollisionManager(const SiconosBulletOptions &options)
   : _with_equality_constraints(false),_options(options)
 {
@@ -656,13 +720,18 @@ void SiconosBulletCollisionManager_impl::createCollisionObjectHelper(
     btobject->setCollisionFlags(btCollisionObject::CF_KINEMATIC_OBJECT);
 
   // put it in the world
+  int collisionFilterGroup = contactor->collision_group;
+  int collisionFilterMask  = 1;
+
 #ifdef QUEUE_STATIC_CONTACTORS
   if(!ds)
-    _queuedCollisionObjects.push_back(btobject);
+  {
+    _queuedCollisionObjects.push_back(std::make_pair(btobject,collisionFilterGroup));
+  }
   else
-    _collisionWorld->addCollisionObject(&*btobject);
+    _collisionWorld->addCollisionObject(&*btobject,collisionFilterGroup,collisionFilterMask);
 #else
-  _collisionWorld->addCollisionObject(&*btobject);
+  _collisionWorld->addCollisionObject(&*btobject,collisionFilterGroup,collisionFilterMask);
 #endif
 
   // create a record to keep track of things
@@ -795,9 +864,9 @@ void SiconosBulletCollisionManager_impl::updateContactorInertia(
   assert(!((localinertia.x() == 0.0
             && localinertia.y() == 0.0
             && localinertia.z() == 0.0)
-           || isinf(localinertia.x())
-           || isinf(localinertia.y())
-           || isinf(localinertia.z()))
+           || std::isinf(localinertia.x())
+           || std::isinf(localinertia.y())
+           || std::isinf(localinertia.z()))
          && "calculateLocalInertia() returned garbage");
   ds->setInertia(localinertia[0],
                  localinertia[1],
@@ -1153,10 +1222,10 @@ void SiconosBulletCollisionManager_impl::createCollisionObject(
   SP::SiconosContactor contactor)
 {
   if(!ch->vertices())
-    throw SiconosException("No vertices matrix specified for convex hull.");
+    THROW_EXCEPTION("No vertices matrix specified for convex hull.");
 
   if(ch->vertices()->size(1) != 3)
-    throw SiconosException("Convex hull vertices matrix must have 3 columns.");
+    THROW_EXCEPTION("Convex hull vertices matrix must have 3 columns.");
 
   // Copy and scale the points
   int rows = ch->vertices()->size(0);
@@ -1296,16 +1365,16 @@ void SiconosBulletCollisionManager_impl::createCollisionObject(
   SP::SiconosContactor contactor)
 {
   if(!mesh->indexes())
-    throw SiconosException("No indexes matrix specified for mesh.");
+    THROW_EXCEPTION("No indexes matrix specified for mesh.");
 
   if((mesh->indexes()->size() % 3) != 0)
-    throw SiconosException("Mesh indexes size must be divisible by 3.");
+    THROW_EXCEPTION("Mesh indexes size must be divisible by 3.");
 
   if(!mesh->vertices())
-    throw SiconosException("No vertices matrix specified for mesh.");
+    THROW_EXCEPTION("No vertices matrix specified for mesh.");
 
   if(mesh->vertices()->size(0) != 3)
-    throw SiconosException("Convex hull vertices matrix must have 3 columns.");
+    THROW_EXCEPTION("Convex hull vertices matrix must have 3 columns.");
 
   // Create Bullet triangle list, either by copying on non-copying method
   // TODO: worldScale on vertices
@@ -1367,12 +1436,12 @@ void SiconosBulletCollisionManager_impl::createCollisionObject(
   SP::SiconosContactor contactor)
 {
   if(!heightmap->height_data())
-    throw SiconosException("No height matrix specified for heightmap.");
+    THROW_EXCEPTION("No height matrix specified for heightmap.");
 
   SP::SiconosMatrix data = heightmap->height_data();
 
   if(!data || data->size(0) < 2 || data->size(1) < 2)
-    throw SiconosException("Height matrix does not have sufficient dimensions "
+    THROW_EXCEPTION("Height matrix does not have sufficient dimensions "
                            "to represent a plane.");
 
   // Create heightfield data for Bullet.  Make a copy in case data
@@ -1505,7 +1574,8 @@ void SiconosBulletCollisionManager_impl::createCollisionObject(
 
   //This version is ok
   double SCALING =1.0;
-  btConvexShape* childShape2 = new btCylinderShapeZ(btVector3(btScalar(SCALING*1),btScalar(SCALING*1),btScalar(0.04)));
+  
+  btConvexShape* childShape2 = new btCylinderShapeZ(btVector3(btScalar(SCALING*1),btScalar(SCALING*1),btScalar(_options.Depth2D)));
   //btConvexShape* colShape3= new btConvex2dShape(childShape2);
   SP::btConvex2dShape btconvex2d1(new btConvex2dShape(childShape2));
 
@@ -1585,7 +1655,7 @@ void SiconosBulletCollisionManager_impl::createCollisionObject(
 
   //This version is ok
   double SCALING =1.0;
-  btConvexShape* childShape0 = new btBoxShape(btVector3(btScalar(SCALING*1),btScalar(SCALING*1),btScalar(0.04)));
+  btConvexShape* childShape0 = new btBoxShape(btVector3(btScalar(SCALING*1),btScalar(SCALING*1),btScalar(_options.Depth2D)));
   //btConvexShape* colShape= new btConvex2dShape(childShape0);
   SP::btConvex2dShape btconvex2d(new btConvex2dShape(childShape0));
 
@@ -1658,10 +1728,10 @@ void SiconosBulletCollisionManager_impl::createCollisionObject(
   // set radius to 1.0 and use scaling instead of setting radius
   // directly, makes it easier to change during update
   if(!ch2d->vertices())
-    throw SiconosException("No vertices matrix specified for convex hull.");
+    THROW_EXCEPTION("No vertices matrix specified for convex hull.");
 
   if(ch2d->vertices()->size(1) != 2)
-    throw SiconosException("2d Convex hull vertices matrix must have 2 columns.");
+    THROW_EXCEPTION("2d Convex hull vertices matrix must have 2 columns.");
 
   // Copy and scale the points
   int rows = ch2d->vertices()->size(0);
@@ -1671,7 +1741,7 @@ void SiconosBulletCollisionManager_impl::createCollisionObject(
   {
     pts[r*3+0] = (*ch2d->vertices())(r, 0) * _options.worldScale;
     pts[r*3+1] = (*ch2d->vertices())(r, 1) * _options.worldScale;
-    pts[r*3+2] = 0.0 * _options.worldScale;
+    pts[r*3+2] = _options.Depth2D * _options.worldScale;
   }
   DEBUG_EXPR_WE(
     for(int r=0; r < rows; r++)
@@ -1702,7 +1772,6 @@ void SiconosBulletCollisionManager_impl::createCollisionObject(
                               SP::RigidBody2dDS,
                               BodyCH2dRecord>
                               (base, ds, ch2d, btconvex2d, bodyShapeMap, contactor);
-  //getchar();
   DEBUG_END("void SiconosBulletCollisionManager_impl::createCollisionObject(..., ch2d, ..) \n");
 }
 
@@ -1853,7 +1922,10 @@ void SiconosBulletCollisionManager_impl::createCollisionObjectsForBodyContactorS
     con = rb2dds->contactors();
     base = rb2dds->q();
   }
-
+  // if ((!rbds) and (!rb2dds))
+  // {
+  //   std::cout << "createCollisionObjectsForBodyContactorSet for static objects" << std::endl;
+  // }
 
   if(!con)
   {
@@ -1880,8 +1952,9 @@ void SiconosBulletCollisionManager_impl::createCollisionObjectsForBodyContactorS
   DEBUG_END("SiconosBulletCollisionManager_impl::createCollisionObjectsForBodyContactorSet(...)\n");
 }
 
-void SiconosBulletCollisionManager::removeBody(const SP::RigidBodyDS& body)
+void SiconosBulletCollisionManager::removeBody(const SP::SecondOrderDS& body)
 {
+
   BodyShapeMap::iterator it(_impl->bodyShapeMap.find(&*body));
   if(it == _impl->bodyShapeMap.end())
     return;
@@ -1894,20 +1967,7 @@ void SiconosBulletCollisionManager::removeBody(const SP::RigidBodyDS& body)
 
   _impl->bodyShapeMap.erase(it);
 }
-void SiconosBulletCollisionManager::removeBody(const SP::RigidBody2dDS& body)
-{
-  BodyShapeMap::iterator it(_impl->bodyShapeMap.find(&*body));
-  if(it == _impl->bodyShapeMap.end())
-    return;
 
-  std::vector<std::shared_ptr<BodyShapeRecord> >::iterator it2;
-  for(it2 = it->second.begin(); it2 != it->second.end(); it2++)
-  {
-    _impl->_collisionWorld->removeCollisionObject(&* (*it2)->btobject);
-  }
-
-  _impl->bodyShapeMap.erase(it);
-}
 /** This class allows to iterate over all the contact points in a
  *  btCollisionWorld, returning a tuple containing the two btCollisionObjects
  *  and the btManifoldPoint.  To be called after
@@ -2121,13 +2181,17 @@ void SiconosBulletCollisionManager::updateInteractions(SP::Simulation simulation
 
   if(! _impl->_queuedCollisionObjects.empty())
   {
+    int collisionFilterMask  = 1;
 
-    std::vector<SP::btCollisionObject>::iterator it;
+    std::vector<std::pair<SP::btCollisionObject,int>>::iterator it;
     for(it = _impl->_queuedCollisionObjects.begin();
         it != _impl->_queuedCollisionObjects.end();
         ++ it)
     {
-      _impl->_collisionWorld->addCollisionObject(&**it);
+      std::pair<SP::btCollisionObject,int> p = *it;
+      int collisionFilterGroup  = p.second;
+      SP::btCollisionObject collisionObject = p.first;
+      _impl->_collisionWorld->addCollisionObject(&*collisionObject,collisionFilterGroup,collisionFilterMask);
     }
     _impl->_queuedCollisionObjects.clear();
   }
@@ -2151,6 +2215,12 @@ void SiconosBulletCollisionManager::updateInteractions(SP::Simulation simulation
   // 3. for each contact point, if there is no interaction, create one
   IterateContactPoints t(_impl->_collisionWorld);
   IterateContactPoints::iterator it, itend=t.end();
+
+  DEBUG_EXPR(
+    int num_contact_points =0;
+    for(it=t.begin(); it!=itend; ++it)  num_contact_points++;
+    std::cout << "Number of contacts points detected by bullet: " << num_contact_points << std::endl; );
+
   DEBUG_PRINT("SiconosBulletCollisionManager :: iterating contact points:\n");
   //getchar();
   for(it=t.begin(); it!=itend; ++it)
@@ -2287,7 +2357,7 @@ void SiconosBulletCollisionManager::updateInteractions(SP::Simulation simulation
 
       else
       {
-        throw SiconosException("Unknown relation type");
+        THROW_EXCEPTION("Unknown relation type");
       }
 
 
@@ -2310,7 +2380,6 @@ void SiconosBulletCollisionManager::updateInteractions(SP::Simulation simulation
       // DEBUG_EXPR(std::cout << nslaw_NewtonImpactFrictionNSL << std::endl;);
       // DEBUG_EXPR(std::cout << nslaw_NewtonImpactRollingFrictionNSL << std::endl;);
 
-      DEBUG_PRINTF("SiconosBulletCollisionManager ::  nslaw->size() = %i\n", nslaw->size());
       // we assume that this test checks if  we deal with 3D problem with RigidBodies
       // Clearly, it will not be sufficient with meshed FE bodies.
       if(nslaw && nslaw_NewtonImpactFrictionNSL)
