@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,13 +30,9 @@ void SiconosBodies::compute()
     _sim->processEvents();
   }
 
-  catch(SiconosException e)
-  {
-    std::cout << e.report() << std::endl;
-  }
   catch(...)
   {
-    std::cout << "Exception caught in SiconosBodies::compute()" << std::endl;
+    Siconos::exception::process();
   }
 }
 
