@@ -49,7 +49,7 @@
 #define DEBUG_NOCOLOR
 //#define DEBUG_STDOUT
 //#define DEBUG_MESSAGES
-#include "debug.h"
+#include "siconos_debug.h"
 
 #define NB_APPROX 10
 
