@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -38,7 +38,7 @@
 /* #define DEBUG_NOCOLOR */
 /* #define DEBUG_MESSAGES */
 /* #define DEBUG_STDOUT */
-#include "debug.h"                     // for DEBUG_PRINTF, DEBUG_EXPR, DEBU...
+#include "siconos_debug.h"                     // for DEBUG_PRINTF, DEBUG_EXPR, DEBU...
 #ifdef DEBUG_MESSAGES
 #include "NumericsVector.h"
 #endif
