@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,11 +29,12 @@
 #include "CSparseMatrix_internal.h"                 // for CSparseMatrix, CS_INT, cs_...
 #include "FrictionContactProblem.h"        // for FrictionContactProblem
 #include "GlobalFrictionContactProblem.h"  // for GlobalFrictionContactProblem
+#include "GlobalRollingFrictionContactProblem.h"  // for GlobalRollingFrictionContactProblem
 #include "NumericsMatrix.h"                // for NumericsMatrix, RawNumeric...
 #include "NumericsSparseMatrix.h"          // for NumericsSparseMatrix, NSM_CSC
 #include "SiconosConfig.h"                 // for WITH_FCLIB
 #include "SparseBlockMatrix.h"             // for SBM_from_csparse, SBM_to_s...
-#include "debug.h"                         // for DEBUG_PRINT, DEBUG_PRINTF
+#include "siconos_debug.h"                         // for DEBUG_PRINT, DEBUG_PRINTF
 #include "timers_interf.h"                 // for MAYBE_UNUSED
 
 // avoid a conflict with old csparse.h in case fclib includes it
@@ -113,6 +114,8 @@ FrictionContactProblem* from_fclib_local(const fclib_local* fclib_problem)
   free(W.p);
   free(W.i);
 
+  NM_reset_versions(problem->M);
+
   return problem;
 
 }
@@ -316,10 +319,10 @@ GlobalFrictionContactProblem* from_fclib_global(const fclib_global* fclib_proble
     problem->M->matrix2->origin = NSM_TRIPLET;
     M->nz = (CS_INT) fclib_problem->M->nz;
     M->p = (CS_INT*) malloc(sizeof(CS_INT)*M->nzmax);
-    int_to_csi(fclib_problem->M->p, M->p, (unsigned) M->nzmax);
+    int_to_csi(fclib_problem->M->p, M->p, (unsigned) M->nz);
   }
   M->i = (CS_INT*) malloc(sizeof(CS_INT)*M->nzmax);
-  int_to_csi(fclib_problem->M->i, M->i, (unsigned) M->nzmax);
+  int_to_csi(fclib_problem->M->i, M->i, (unsigned) M->nz);
 
 
   problem->H = NM_create(NM_SPARSE, fclib_problem->H->m, fclib_problem->H->n);
@@ -358,6 +361,8 @@ GlobalFrictionContactProblem* from_fclib_global(const fclib_global* fclib_proble
   H->i = (CS_INT*) malloc(sizeof(CS_INT)*H->nzmax);
   int_to_csi(fclib_problem->H->i, H->i, (unsigned) H->nz);
 
+ 
+  NM_reset_versions(problem->M);
   return problem;
 
 }
@@ -379,13 +384,6 @@ GlobalFrictionContactProblem* globalFrictionContact_fclib_read(const char *path)
 }
 
 
-int globalFrictionContact_fclib_write(
-  GlobalFrictionContactProblem* problem,
-  char * title,
-  char * description,
-  char * mathInfo,
-  const char *path);
-
 int globalFrictionContact_fclib_write(
   GlobalFrictionContactProblem* problem,
   char * title,
@@ -496,4 +494,116 @@ int globalFrictionContact_fclib_write(
 
 }
 
+
+int globalRollingFrictionContact_fclib_write(
+  GlobalRollingFrictionContactProblem* problem,
+  char * title,
+  char * description,
+  char * mathInfo,
+  const char *path)
+{
+  int rinfo = 0;
+
+  DEBUG_PRINTF("construction of fclib_problem in %s with title = %s and description = %s\n", path, title, description);
+  if(problem->numberOfContacts == 0)
+  {
+    DEBUG_PRINT("zero contacts");
+    return rinfo;
+
+  }
+  /* globalFrictionContact_display(problem); */
+  /* FILE * file  =  fopen("toto.dat", "w"); */
+  /* globalFrictionContact_printInFile(problem, file); */
+
+  fclib_global_rolling *fclib_problem;
+  fclib_problem = (fclib_global_rolling*)malloc(sizeof(fclib_global_rolling));
+
+  fclib_problem->info = (struct fclib_info*)malloc(sizeof(struct fclib_info)) ;
+
+  fclib_problem->info->title = title;
+  fclib_problem->info->description = description;
+  fclib_problem->info->math_info = mathInfo;
+
+
+
+  fclib_problem->spacedim = problem->dimension;
+  fclib_problem->mu = problem->mu;
+  fclib_problem->mu_r = problem->mu_r;
+  fclib_problem->w =  problem->b;
+  fclib_problem->f =  problem->q;
+
+  /* only sparse storage */
+  assert(problem->M->matrix2);
+  assert(problem->H->matrix2);
+
+
+  /* only coordinates (triplet) */
+  if(problem->M->matrix2->triplet)
+  {
+    fclib_problem->M = (struct fclib_matrix*)malloc(sizeof(struct fclib_matrix));
+    fclib_problem->M->n = (int) problem->M->matrix2->triplet->n;
+    fclib_problem->M->m = (int) problem->M->matrix2->triplet->m;
+    fclib_problem->M->nzmax= (int) problem->M->matrix2->triplet->nzmax;
+
+    fclib_problem->M->p= (int*) malloc(sizeof(int)*(problem->M->matrix2->triplet->nzmax));
+    csi_to_int(problem->M->matrix2->triplet->p, fclib_problem->M->p,
+               (unsigned) problem->M->matrix2->triplet->nzmax);
+    fclib_problem->M->i= (int*) malloc(sizeof(int)*(problem->M->matrix2->triplet->nzmax));
+    csi_to_int(problem->M->matrix2->triplet->i, fclib_problem->M->i,
+               (unsigned) problem->M->matrix2->triplet->nzmax);
+    fclib_problem->M->x= problem->M->matrix2->triplet->x;
+    fclib_problem->M->nz= (int) problem->M->matrix2->triplet->nz;
+    fclib_problem->M->info=NULL;
+  }
+  else
+  {
+    fprintf(stderr, "globalRollingFrictionContact_fclib_write only implemented for triplet storage.\n");
+    exit(EXIT_FAILURE); ;
+  }
+
+  if(problem->H->matrix2->triplet)
+  {
+    fclib_problem->H = (struct fclib_matrix*)malloc(sizeof(struct fclib_matrix));
+    fclib_problem->H->n = (int) problem->H->matrix2->triplet->n;
+    fclib_problem->H->m = (int) problem->H->matrix2->triplet->m;
+    fclib_problem->H->nzmax= (int) problem->H->matrix2->triplet->nzmax;
+    fclib_problem->H->p= (int*) malloc(sizeof(int)*problem->H->matrix2->triplet->nzmax);
+    csi_to_int(problem->H->matrix2->triplet->p, fclib_problem->H->p,
+               (unsigned) problem->H->matrix2->triplet->nzmax);
+    fclib_problem->H->i= (int*) malloc(sizeof(int)*problem->H->matrix2->triplet->nzmax);
+    csi_to_int(problem->H->matrix2->triplet->i, fclib_problem->H->i,
+               (unsigned) problem->H->matrix2->triplet->nzmax);
+    fclib_problem->H->x= problem->H->matrix2->triplet->x;
+    fclib_problem->H->nz= (int) problem->H->matrix2->triplet->nz;
+    fclib_problem->H->info=NULL;
+  }
+  else
+  {
+    fprintf(stderr, "globalRollingFrictionContact_fclib_write only implemented for triplet storage.\n");
+    exit(EXIT_FAILURE); ;
+  }
+
+  fclib_problem->G = NULL;
+  fclib_problem->b = NULL;
+
+
+
+  DEBUG_PRINT("write in fclib of fclib_problem\n");
+
+  rinfo = fclib_write_global_rolling(fclib_problem, path);
+  DEBUG_PRINT("end of write in fclib of fclib_problem\n");
+
+  free(fclib_problem->M->p);
+  free(fclib_problem->M->i);
+  free(fclib_problem->H->p);
+  free(fclib_problem->H->i);
+  free(fclib_problem->H);
+  free(fclib_problem->M);
+  free(fclib_problem->info);
+  free(fclib_problem);
+
+  return rinfo;
+
+}
+
 #endif
