@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -26,7 +26,7 @@
 #include "NumericsFwd.h"                       // for SolverOptions, Rolling...
 #include "RollingFrictionContactProblem.h"     // for RollingFrictionContact...
 #include "SolverOptions.h"                     // for SolverOptions, SICONOS...
-#include "debug.h"                             // for DEBUG_PRINTF, DEBUG_BEGIN
+#include "siconos_debug.h"                             // for DEBUG_PRINTF, DEBUG_BEGIN
 #include "numerics_verbose.h"                  // for numerics_printf, numer...
 #include "rolling_fc_Solvers.h"              // for RollingComputeErrorPtr
 #include "rolling_fc3d_compute_error.h"        // for rolling_fc3d_compute_e...
@@ -105,30 +105,47 @@ void rolling_fc3d_nsgs_initialize_local_solver(RollingSolverPtr* solve, RollingU
   }
 }
 
+// Never used ...
+/* static */
+/* unsigned int* allocShuffledContacts(RollingFrictionContactProblem *problem, */
+/*                                     SolverOptions *options) */
+/* { */
+/*   unsigned int *scontacts = 0; */
+/*   unsigned int nc = problem->numberOfContacts; */
+/*   if(options->iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE] == SICONOS_FRICTION_3D_NSGS_SHUFFLE_TRUE|| */
+/*       options->iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE] == SICONOS_FRICTION_3D_NSGS_SHUFFLE_TRUE_EACH_LOOP) */
+/*   { */
+/*     if(options->iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE_SEED] >0) */
+/*     { */
+/*       srand((unsigned int)options->iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE_SEED]); */
+/*     } */
+/*     else */
+/*       srand(1); */
+/*     scontacts = (unsigned int *) malloc(nc * sizeof(unsigned int)); */
+/*     for(unsigned int i = 0; i < nc ; ++i) */
+/*     { */
+/*       scontacts[i] = i; */
+/*     } */
+/*     uint_shuffle(scontacts, nc); */
+/*   } */
+/*   return scontacts; */
+/* } */
 
 static
-unsigned int* allocShuffledContacts(RollingFrictionContactProblem *problem,
+unsigned int* allocfreezingContacts(RollingFrictionContactProblem *problem,
                                     SolverOptions *options)
 {
-  unsigned int *scontacts = 0;
+  unsigned int *fcontacts = 0;
   unsigned int nc = problem->numberOfContacts;
-  if(options->iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE] == SICONOS_FRICTION_3D_NSGS_SHUFFLE_TRUE||
-      options->iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE] == SICONOS_FRICTION_3D_NSGS_SHUFFLE_TRUE_EACH_LOOP)
+  if(options->iparam[SICONOS_FRICTION_3D_NSGS_FREEZING_CONTACT] > 0)
   {
-    if(options->iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE_SEED] >0)
-    {
-      srand((unsigned int)options->iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE_SEED]);
-    }
-    else
-      srand(1);
-    scontacts = (unsigned int *) malloc(nc * sizeof(unsigned int));
+    fcontacts = (unsigned int *) malloc(nc * sizeof(unsigned int));
     for(unsigned int i = 0; i < nc ; ++i)
     {
-      scontacts[i] = i;
+      fcontacts[i] = 0;
     }
-    uint_shuffle(scontacts, nc);
   }
-  return scontacts;
+  return fcontacts;
 }
 
 static
@@ -161,15 +178,26 @@ void performRelaxation(double localreaction[5], double *oldreaction, double omeg
   localreaction[4] = omega*localreaction[4]+(1.0-omega)*oldreaction[4];
 }
 
+
 static
-void accumulateLightErrorSum(double *light_error_sum, double localreaction[5],
-                             double *oldreaction)
+double light_error_squared( double localreaction[5],
+                            double *oldreaction)
 {
-  *light_error_sum += (pow(oldreaction[0] - localreaction[0], 2) +
-                       pow(oldreaction[1] - localreaction[1], 2) +
-                       pow(oldreaction[2] - localreaction[2], 2) +
-                       pow(oldreaction[3] - localreaction[3], 2) +
-                       pow(oldreaction[4] - localreaction[4], 2));
+  return (pow(oldreaction[0] - localreaction[0], 2) +
+          pow(oldreaction[1] - localreaction[1], 2) +
+          pow(oldreaction[2] - localreaction[2], 2) +
+          pow(oldreaction[3] - localreaction[3], 2) +
+          pow(oldreaction[4] - localreaction[4], 2));
+}
+
+static
+double squared_norm(double localreaction[5])
+{
+  return (pow(localreaction[0], 2) +
+          pow(localreaction[1], 2) +
+          pow(localreaction[2], 2) +
+          pow(localreaction[3], 2) +
+          pow(localreaction[4], 2));
 }
 
 static
@@ -203,13 +231,13 @@ void acceptLocalReactionUnconditionally(unsigned int contact,
 }
 
 static
-double calculateLightError(double light_error_sum, unsigned int nc, double *reaction)
+double calculateLightError(double light_error_sum, unsigned int nc, double *reaction, double * norm_r)
 {
   DEBUG_BEGIN("calculateLightError(...)\n");
   double error = sqrt(light_error_sum);
-  double norm_r = cblas_dnrm2(nc*5, reaction, 1);
-  if(fabs(norm_r) > DBL_EPSILON)
-    error /= norm_r;
+  *norm_r = cblas_dnrm2(nc*5, reaction, 1);
+  if(fabs(*norm_r) > DBL_EPSILON)
+    error /= (*norm_r);
   DEBUG_PRINTF("error = %f\n", error);
   DEBUG_END("calculateLightError(...)\n");
   return error;
@@ -284,12 +312,12 @@ int determine_convergence(double error, double tolerance, int iter,
   {
     hasNotConverged = 0;
     numerics_printf("--------------- RFC3D - NSGS - Iteration %i "
-                    "Residual = %14.7e < %7.3e\n", iter, error, tolerance);
+                    "Residual = %14.7e < %7.3e", iter, error, tolerance);
   }
   else
   {
     numerics_printf("--------------- RFC3D - NSGS - Iteration %i "
-                    "Residual = %14.7e > %7.3e\n", iter, error, tolerance);
+                    "Residual = %14.7e > %7.3e", iter, error, tolerance);
   }
   return hasNotConverged;
 }
@@ -384,6 +412,7 @@ void rolling_fc3d_nsgs(RollingFrictionContactProblem* problem, double *reaction,
   double norm_q = cblas_dnrm2(nc*5, problem->q, 1);
   double omega = dparam[SICONOS_FRICTION_3D_NSGS_RELAXATION_VALUE];
 
+  double  norm_r[] = {1e24};
   RollingSolverPtr local_solver = NULL;
   RollingUpdatePtr update_localproblem = NULL;
   RollingFreeSolverNSGSPtr freeSolver = NULL;
@@ -398,6 +427,7 @@ void rolling_fc3d_nsgs(RollingFrictionContactProblem* problem, double *reaction,
   int hasNotConverged = 1;
   unsigned int contact; /* Number of the current row of blocks in M */
   unsigned int *scontacts = NULL;
+  unsigned int *freeze_contacts = NULL;
 
   if(*info == 0)
     return;
@@ -418,7 +448,7 @@ void rolling_fc3d_nsgs(RollingFrictionContactProblem* problem, double *reaction,
       &computeError,
       problem, localproblem, options);
 
-  scontacts = allocShuffledContacts(problem, options);
+  freeze_contacts = allocfreezingContacts(problem, options);
 
   /*****  Check solver options *****/
   if(!(iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE] == SICONOS_FRICTION_3D_NSGS_SHUFFLE_FALSE
@@ -452,9 +482,10 @@ void rolling_fc3d_nsgs(RollingFrictionContactProblem* problem, double *reaction,
   /* A special case for the most common options (should correspond
    * with mechanics_run.py **/
   if(iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE] == SICONOS_FRICTION_3D_NSGS_SHUFFLE_FALSE
-      && iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE] == SICONOS_FRICTION_3D_NSGS_RELAXATION_FALSE
-      && iparam[SICONOS_FRICTION_3D_NSGS_FILTER_LOCAL_SOLUTION] == SICONOS_FRICTION_3D_NSGS_FILTER_LOCAL_SOLUTION_TRUE
-      && iparam[SICONOS_FRICTION_3D_IPARAM_ERROR_EVALUATION] == SICONOS_FRICTION_3D_NSGS_ERROR_EVALUATION_LIGHT)
+     && iparam[SICONOS_FRICTION_3D_NSGS_FREEZING_CONTACT] == 0
+     && iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE] == SICONOS_FRICTION_3D_NSGS_RELAXATION_FALSE
+     && iparam[SICONOS_FRICTION_3D_NSGS_FILTER_LOCAL_SOLUTION] == SICONOS_FRICTION_3D_NSGS_FILTER_LOCAL_SOLUTION_TRUE
+     && iparam[SICONOS_FRICTION_3D_IPARAM_ERROR_EVALUATION] == SICONOS_FRICTION_3D_NSGS_ERROR_EVALUATION_LIGHT)
   {
     while((iter < itermax) && (hasNotConverged > 0))
     {
@@ -472,14 +503,14 @@ void rolling_fc3d_nsgs(RollingFrictionContactProblem* problem, double *reaction,
                            problem, localproblem, reaction, localsolver_options,
                            localreaction);
 
-        accumulateLightErrorSum(&light_error_sum, localreaction, &reaction[contact*5]);
+        light_error_sum += light_error_squared(localreaction, &reaction[contact*5]);
 
         /* #if 0 */
         acceptLocalReactionFiltered(localproblem, localsolver_options,
                                     contact, iter, reaction, localreaction);
       }
 
-      error = calculateLightError(light_error_sum, nc, reaction);
+      error = calculateLightError(light_error_sum, nc, reaction, norm_r);
 
       hasNotConverged = determine_convergence(error, tolerance, iter, options);
 
@@ -492,11 +523,24 @@ void rolling_fc3d_nsgs(RollingFrictionContactProblem* problem, double *reaction,
    * common cases to avoid checking booleans on every iteration. **/
   else
   {
+
     while((iter < itermax) && (hasNotConverged > 0))
     {
       ++iter;
       double light_error_sum = 0.0;
+      double light_error_2 = 0.0;
+
       rolling_fc3d_set_internalsolver_tolerance(problem, options, localsolver_options, error);
+      int number_of_freezed_contact=0;
+      if(iparam[SICONOS_FRICTION_3D_NSGS_FREEZING_CONTACT] >0)
+      {
+        for(unsigned int i = 0 ; i < nc ; ++i)
+        {
+        if (freeze_contacts[i] >0)
+          number_of_freezed_contact++;
+        }
+      }
+      numerics_printf_verbose(2,"Number of freezed contacts  = %i",  number_of_freezed_contact);
 
       for(unsigned int i = 0 ; i < nc ; ++i)
       {
@@ -510,6 +554,16 @@ void rolling_fc3d_nsgs(RollingFrictionContactProblem* problem, double *reaction,
         else
           contact = i;
 
+        if(iparam[SICONOS_FRICTION_3D_NSGS_FREEZING_CONTACT] >0)
+        {
+          if (freeze_contacts[contact] >0)
+          {
+            /* we skip freeze contacts */
+            freeze_contacts[contact] -=  1;
+            //printf("Contact % i is freezed for %i remaining steps\n", contact, freeze_contacts[contact]);
+            continue;
+          }
+        }
 
         solveLocalReaction(update_localproblem, local_solver, contact,
                            problem, localproblem, reaction, localsolver_options,
@@ -518,7 +572,9 @@ void rolling_fc3d_nsgs(RollingFrictionContactProblem* problem, double *reaction,
         if(iparam[SICONOS_FRICTION_3D_NSGS_RELAXATION] == SICONOS_FRICTION_3D_NSGS_RELAXATION_TRUE)
           performRelaxation(localreaction, &reaction[contact*5], omega);
 
-        accumulateLightErrorSum(&light_error_sum, localreaction, &reaction[contact*5]);
+        light_error_2= light_error_squared(localreaction, &reaction[contact*5]);
+        light_error_sum += light_error_2;
+
 
         /* int test =100; */
         /* if (contact == test) */
@@ -527,25 +583,46 @@ void rolling_fc3d_nsgs(RollingFrictionContactProblem* problem, double *reaction,
         /*   printf("localreaction[%i] = %16.8e\n",2,localreaction[0]); */
         /* } */
 
-
+        if(iparam[SICONOS_FRICTION_3D_NSGS_FREEZING_CONTACT] >0)
+        {
+          if ((light_error_2*squared_norm(localreaction) <= tolerance*tolerance/(nc*nc*10)
+               || squared_norm(localreaction) <=  (*norm_r* *norm_r/(nc*nc*1000)))
+              && iter >=10)
+          {
+            //printf("Number of freezed contacts  = %i\n",  number_of_freezed_contact);
+            /* we  freeze the contact for n iterations*/
+            /* printf("first criteria : light_error_2*squared_norm(localreaction) <= tolerance*tolerance/(nc*nc*10) ==> %e <= %e\n", light_error_2*squared_norm(localreaction), tolerance*tolerance/(nc*nc*10)); */
+            /* printf("second criteria :  squared_norm(localreaction) <=  (*norm_r* *norm_r/(nc*nc))/1000. ==> %e <= %e\n",  squared_norm(localreaction) ,  (*norm_r* *norm_r/(nc*nc))/1000.); */
+            // printf("Contact % i is freezed for %i steps\n", contact,  iparam[SICONOS_FRICTION_3D_NSGS_FREEZING_CONTACT]);
+            if (number_of_freezed_contact < nc-1)
+            {
+              number_of_freezed_contact++;
+              freeze_contacts[contact] = iparam[SICONOS_FRICTION_3D_NSGS_FREEZING_CONTACT] ;
+            }
+            else
+            {
+              numerics_printf_verbose(2,"Number of freezed contacts too large w.r.t number of contact. we defreeze all contacts\n");
+              for(unsigned int c = 0 ; c < nc ; ++c)  freeze_contacts[c] =0;
+            }
+          }
+        }
         if(iparam[SICONOS_FRICTION_3D_NSGS_FILTER_LOCAL_SOLUTION] == SICONOS_FRICTION_3D_NSGS_FILTER_LOCAL_SOLUTION_TRUE)
           acceptLocalReactionFiltered(localproblem, localsolver_options,
                                       contact, iter, reaction, localreaction);
         else
           acceptLocalReactionUnconditionally(contact, reaction, localreaction);
 
-
-
       }
 
+
       if(iparam[SICONOS_FRICTION_3D_IPARAM_ERROR_EVALUATION] == SICONOS_FRICTION_3D_NSGS_ERROR_EVALUATION_LIGHT)
       {
-        error = calculateLightError(light_error_sum, nc, reaction);
+        error = calculateLightError(light_error_sum, nc, reaction, norm_r);
         hasNotConverged = determine_convergence(error, tolerance, iter, options);
       }
       else if(iparam[SICONOS_FRICTION_3D_IPARAM_ERROR_EVALUATION] == SICONOS_FRICTION_3D_NSGS_ERROR_EVALUATION_LIGHT_WITH_FULL_FINAL)
       {
-        error = calculateLightError(light_error_sum, nc, reaction);
+        error = calculateLightError(light_error_sum, nc, reaction, norm_r);
         hasNotConverged = determine_convergence_with_full_final(problem,  options, computeError,
                           reaction, velocity,
                           &tolerance, norm_q, error,
@@ -561,9 +638,21 @@ void rolling_fc3d_nsgs(RollingFrictionContactProblem* problem, double *reaction,
       }
 
       statsIterationCallback(problem, options, reaction, velocity, error);
-    }
-  }
 
+    }
+    /* if(iparam[SICONOS_FRICTION_3D_NSGS_FREEZING_CONTACT] >0) */
+    /* { */
+    /*   int frozen_contact=0; */
+    /*   for(unsigned int i = 0 ; i < nc ; ++i) */
+    /*   { */
+    /*     if (freeze_contacts[contact] >0) */
+    /*     { */
+    /*       frozen_contact++; */
+    /*     } */
+    /*   } */
+    /*   printf("number of frozen contacts : %i\n", frozen_contact ); */
+    /* } */
+  }
 
   /* Full criterium */
   if(iparam[SICONOS_FRICTION_3D_IPARAM_ERROR_EVALUATION] == SICONOS_FRICTION_3D_NSGS_ERROR_EVALUATION_LIGHT_WITH_FULL_FINAL)
@@ -599,6 +688,7 @@ void rfc3d_nsgs_set_default(SolverOptions* options)
   /* options->iparam[SICONOS_FRICTION_3D_IPARAM_INTERNAL_ERROR_STRATEGY] = SICONOS_FRICTION_3D_INTERNAL_ERROR_STRATEGY_ADAPTIVE_N_CONTACT; */
   options->iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE] =  SICONOS_FRICTION_3D_NSGS_SHUFFLE_FALSE;
   options->iparam[SICONOS_FRICTION_3D_NSGS_SHUFFLE_SEED] = 0;
+  options->iparam[SICONOS_FRICTION_3D_NSGS_FREEZING_CONTACT] = 0;
   options->iparam[SICONOS_FRICTION_3D_NSGS_FILTER_LOCAL_SOLUTION] = SICONOS_FRICTION_3D_NSGS_FILTER_LOCAL_SOLUTION_FALSE;
   options->iparam[SICONOS_FRICTION_3D_NSGS_RELAXATION] = SICONOS_FRICTION_3D_NSGS_RELAXATION_FALSE;
   options->iparam[SICONOS_FRICTION_3D_IPARAM_ERROR_EVALUATION_FREQUENCY] = 0;
