@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -741,7 +741,8 @@ void gmp_as_mlcp(GenericMechanicalProblem* pInProblem, double *reaction, double
     for(size_t i = 0; i < (size_t)Me_size; ++i) reaction[i] = -Qreduced[i];
     NumericsMatrix M;
     NM_fill(&M, NM_DENSE, Me_size, Me_size, reducedProb);
-    *info = NM_gesv(&M, reaction, true);
+    // *info = NM_gesv(&M, reaction, true);
+    *info = NM_LU_solve(&M, reaction, 1);
     M.matrix0 = NULL;
     NM_clear(&M);
     goto END_GMP3;
