@@ -2,7 +2,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@
 #include "LinearComplementarityProblem.h"  // for LinearComplementarityProblem
 /* #define DEBUG_STDOUT */
 /* #define DEBUG_MESSAGES */
-#include "debug.h"                         // for DEBUG_PRINT
+#include "siconos_debug.h"                         // for DEBUG_PRINT
 
 void Projection_ConvexQP_LCP(void *cqpIn, double *x, double *PX)
 {
