@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,13 +25,13 @@
 #include "ConvexQP_computeError.h"  // for convexQP_compute_error
 #include "ConvexQP_cst.h"           // for SICONOS_CONVEXQP_ADMM_IPARAM_ACCE...
 #include "NumericsFwd.h"            // for SolverOptions, ConvexQP, Numerics...
-#include "NumericsMatrix.h"         // for NM_gemv, NM_clear, NM_gesv_expert
+#include "NumericsMatrix.h"         // for NM_gemv, NM_clear, ...
 #include "NumericsSparseMatrix.h"   // for NSM_TRIPLET, NumericsSparseMatrix
 #include "SolverOptions.h"          // for SolverOptions, solver_options_nul...
 /* #define DEBUG_NOCOLOR */
 /* #define DEBUG_MESSAGES */
 /* #define DEBUG_STDOUT */
-#include "debug.h"                  // for DEBUG_EXPR, DEBUG_PRINT, DEBUG_PR...
+#include "siconos_debug.h"                  // for DEBUG_EXPR, DEBUG_PRINT, DEBUG_PR...
 #include "numerics_verbose.h"       // for numerics_printf_verbose, numerics...
 #include "SiconosBlas.h"                  // for cblas_daxpy, cblas_dcopy, cblas_d...
 
@@ -159,7 +159,7 @@ void convexQP_ADMM(ConvexQP* problem,
 
     for(size_t k =0; k< n; k++)
     {
-      NM_zentry(problem->A, k, k, 1);
+      NM_entry(problem->A, k, k, 1);
     }
     DEBUG_EXPR(NM_display(problem->A));
 
@@ -203,7 +203,7 @@ void convexQP_ADMM(ConvexQP* problem,
   double * tmp =  options->dWork;
 
   /* Compute M + rho A^T A (storage in M)*/
-  NumericsMatrix *Atrans;
+  NumericsMatrix *Atrans=0;
   if(!A)
   {
     if(M->storageType != A->storageType)
@@ -300,7 +300,8 @@ void convexQP_ADMM(ConvexQP* problem,
 
     /* Linear system solver */
     /* cblas_dcopy(n , w_k , 1 , z, 1); */
-    NM_gesv_expert(W,z,NM_KEEP_FACTORS);
+    // NM_gesv_expert(W,z,NM_KEEP_FACTORS);
+    NM_LU_solve(W, z, 1);
     DEBUG_PRINT("z:");
     DEBUG_EXPR(NV_display(z,n));
 
@@ -563,7 +564,8 @@ void convexQP_ADMM(ConvexQP* problem,
   }
   else
   {
-    NM_clear(Atrans);
+    if(Atrans)
+      NM_clear(Atrans);
   }
 
 
