@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -28,12 +28,18 @@
 #include <stdlib.h>         // for malloc
 #include "CSparseMatrix.h"  // for CS_INT, CSparseMatrix
 #include "NumericsFwd.h"    // for NumericsMatrix, NumericsSparseMatrix, Spa...
+#include "NumericsDataVersion.h" // Versioning
+#include "NumericsSparseMatrix.h" // for NSM_linear_solver typedef
 #include "SiconosConfig.h" // for BUILD_AS_CPP, SICONOS_HAS_MP // IWYU pragma: keep
 #include "NM_MPI.h"
 #ifndef __cplusplus
 #include <stdbool.h>        // for bool
 #endif
 
+#ifdef WITH_OPENSSL
+#include <openssl/sha.h>
+#endif
+
 /** \struct NumericsMatrixInternalData NumericsMatrix.h
  * Structure for simple workspaces
  */
@@ -45,12 +51,29 @@ typedef struct
   size_t dWorkSize; /**< size of dWork */
   double *dWork; /**< double workspace */
   bool isLUfactorized; /**<  true if the matrix has already been LU-factorized */
-  bool isInversed; /**<  true if the matrix containes its inverse (in place inversion) */
+  bool isCholeskyfactorized; /**<  true if the matrix has already been Cholesky factorized */
+  bool isLDLTfactorized; /**<  true if the matrix has already been LDLT factorized */
+  bool isInversed; /**<  true if the matrix contains its inverse (in place inversion) */
 #ifdef SICONOS_HAS_MPI
   MPI_Comm mpi_comm; /**< optional mpi communicator */
 #endif
+#ifdef WITH_OPENSSL
+  unsigned int values_sha1_count; /**< counter for sha1 */
+  unsigned char values_sha1[SHA_DIGEST_LENGTH]; /**< sha1 hash of
+                                                 * values. Matrices of
+                                                 * differents sizes may have
+                                                 * the same hash */
+#endif
 } NumericsMatrixInternalData;
 
+/*! Available types of storage for NumericsMatrix */
+typedef enum NumericsMatrix_types {
+  NM_DENSE,        /**< dense format */
+  NM_SPARSE_BLOCK, /**< sparse block format */
+  NM_SPARSE,          /**< compressed column format */
+  NM_UNKNOWN, /** unset. Used in NM_null */
+} NM_types;
+
 /** \struct NumericsMatrix NumericsMatrix.h
     Interface to different type of matrices in numerics component.
 
@@ -58,7 +81,7 @@ typedef struct
 */
 struct NumericsMatrix
 {
-  int storageType; /**< the type of storage:
+  NM_types storageType; /**< the type of storage:
                       0: dense (double*),
                       1: SparseBlockStructuredMatrix,
                       2: classical sparse (csc, csr or triplet) via CSparse (from T. Davis)*/
@@ -70,6 +93,11 @@ struct NumericsMatrix
 
   NumericsMatrixInternalData* internalData; /**< internal storage, used for workspace among other things */
 
+  NumericsDataVersion version; /*< version of dense storage */
+
+  NumericsMatrix* destructible; /**< pointer on the destructible
+                                 * matrix, by default points toward
+                                 * the matrix itself */
 };
 
 typedef struct
@@ -84,14 +112,7 @@ typedef struct
 /*! RawNumericsMatrix is used without conversion in python */
 typedef NumericsMatrix RawNumericsMatrix;
 
-/*! Available types of storage for NumericsMatrix */
-typedef enum NumericsMatrix_types {
-  NM_DENSE,        /**< dense format */
-  NM_SPARSE_BLOCK, /**< sparse block format */
-  NM_SPARSE,          /**< compressed column format */
-} NM_types;
 
-/*! option for gesv factorization */
 typedef enum {
   NM_NONE,          /**< keep nothing */
   NM_KEEP_FACTORS,  /**< keep all the factorization data (useful to reuse the factorization) */
@@ -111,13 +132,14 @@ extern "C"
    */
   RawNumericsMatrix* NM_new(void);
   RawNumericsMatrix* NM_eye(int size);
+
   /** create a NumericsMatrix and allocate the memory according to the matrix type
    * \param storageType the type of storage
    * \param size0 number of rows
    * \param size1 number of columns
    * \return a pointer to a NumericsMatrix
    */
-  RawNumericsMatrix* NM_create(int storageType, int size0, int size1);
+  RawNumericsMatrix* NM_create(NM_types storageType, int size0, int size1);
 
   /** create a NumericsMatrix and possibly set the data
    * \param storageType the type of storage
@@ -145,8 +167,10 @@ extern "C"
    *  be set to NM_SPARSE.
    * \param[in] A a NumericsMatrix
    * \param[in,out] B a NumericsMatrix
+   * \param threshold if the original matrix is dense, a threshold can be applied
+   * on the absolute value of the entries
    */
-  void NM_copy_to_sparse(const NumericsMatrix* const A, NumericsMatrix* B);
+  void NM_copy_to_sparse(const NumericsMatrix* const A, NumericsMatrix* B, double threshold);
 
   /** create a NumericsMatrix similar to the another one. The structure is the same
    * \param mat the model matrix
@@ -201,7 +225,7 @@ extern "C"
    * \param data pointer to the matrix data. If NULL, all matrixX fields are
    * set to NULL
    */
-  void NM_fill(NumericsMatrix* M, int storageType, int size0, int size1, void* data);
+  void NM_fill(NumericsMatrix* M, NM_types storageType, int size0, int size1, void* data);
 
   /** new NumericsMatrix with sparse storage from minimal set of data
    * \param[in] size0 number of rows
@@ -222,6 +246,50 @@ extern "C"
    */
   void NM_null(NumericsMatrix* A);
 
+  /** Check if a matrix is destructible.
+   * \param[in] A the NumericsMatrix
+   * \return true if the matrix is destructible */
+  bool NM_destructible(const NumericsMatrix* A);
+
+  /** Preservation of a matrix before in-place transformations such as
+   * factorizations.
+   * \param[in] A the NumericsMatrix
+   * \return a pointer on the preserved Matrix;
+   */
+  RawNumericsMatrix* NM_preserve(NumericsMatrix* A);
+
+  /** Set the matrix as destructible, clear the preserved data.
+   * \param[in] A the NumericsMatrix
+   * \return a pointer on the Matrix;
+   */
+  RawNumericsMatrix* NM_unpreserve(NumericsMatrix* A);
+
+  /** Check for a previous LU factorization.
+   * \param[in] A the NumericsMatrix
+   * \return true if the matrix has been LU factorized.
+   */
+  bool NM_LU_factorized(const NumericsMatrix* const A);
+
+  /** Check for a previous Cholesky factorization.
+   * \param[in] A the NumericsMatrix
+   * \return true if the matrix has been Cholesky factorized.
+   */
+  bool NM_Cholesky_factorized(const NumericsMatrix* const A);
+
+  /** Check for a previous LDLT factorization.
+   * \param[in] A the NumericsMatrix
+   * \return true if the matrix has been Cholesky factorized.
+   */
+  bool NM_LDLT_factorized(const NumericsMatrix* const A);
+
+  /** Set the factorization flag.
+   * \param[in] A the NumericsMatrix,
+   * \param[in] flag a boolean.
+   */
+  void NM_set_LU_factorized(NumericsMatrix* A, bool flag);
+  void NM_set_Cholesky_factorized(NumericsMatrix* A, bool flag);
+  void NM_set_LDLT_factorized(NumericsMatrix* A, bool flag);
+
   /** update the size of the matrix based on the matrix data
    * \param[in,out] A the matrix which size is updated*/
   void NM_update_size(NumericsMatrix* A);
@@ -245,26 +313,40 @@ extern "C"
    */
   void NM_triplet_alloc(NumericsMatrix* A, CS_INT nzmax);
 
-  /** Allocate a csr matrix in A
-   * \param A the matrix
-   * \param nzmax number of non-zero elements
-   */
-  void NM_csr_alloc(NumericsMatrix* A, CS_INT nzmax);
 
   /** Free memory for a NumericsMatrix. Warning: call this function only if you are sure that
       memory has been allocated for the structure in Numerics. This function is assumed that the memory is "owned" by this structure.
       Note that this function does not free m.
       \param m the matrix to be deleted.
    */
+
   void NM_clear(NumericsMatrix* m);
 
+  NumericsMatrix *  NM_free(NumericsMatrix* m);
+
+  /** Free memory for a NumericsMatrix except the dense matrix that is assumed not to be owned.
+      \param m the matrix to be cleared.
+   */
+  void NM_clear_not_dense(NumericsMatrix* m);
+  NumericsMatrix *  NM_free_not_dense(NumericsMatrix* m);
+  /** Free memory for a NumericsMatrix except the SBM matrix that is assumed not to be owned.
+      Note that this function does not free m.
+      \param m the matrix to be cleared.
+   */
+  void NM_clear_not_SBM(NumericsMatrix* m);
+  NumericsMatrix * NM_free_not_SBM(NumericsMatrix* m);
+  
+
+
+
+ 
   /** Free memory for a NumericsMatrix except for a given storage. Warning: call this function only if you are sure that
       memory has been allocated for the structure in Numerics. This function is assumed that the memory is "owned" by this structure.
       Note that this function does not free m.
       \param m the matrix to be deleted.
       \param storageType to be kept.
    */
-  void NM_clear_other_storages(NumericsMatrix* M, int storageType);
+  void NM_clear_other_storages(NumericsMatrix* M, NM_types storageType);
 
   /**************************************************/
   /** setters and getters               *************/
@@ -272,14 +354,26 @@ extern "C"
 
   /** insert an non zero entry into a NumericsMatrix.
    * for storageType = NM_SPARSE, a conversion to triplet is done for performing the entry in the
-   * matrix. This method is expensice in terms of memory management. For a lot of entries, use
+   * matrix. This method is expensive in terms of memory management. For a lot of entries, use
+   * preferably a triplet matrix.
+   * \param M the NumericsMatrix
+   * \param i row index
+   * \param j column index
+   * \param val the value to be inserted.
+   * \param threshold a threshold to filter the small value in magnitude (useful for dense to sparse conversion)
+   */
+  void NM_zentry(NumericsMatrix* M, int i, int j, double val, double threshold);
+
+  /** insert an entry into a NumericsMatrix.
+   * for storageType = NM_SPARSE, a conversion to triplet is done for performing the entry in the
+   * matrix. This method is expensive in terms of memory management. For a lot of entries, use
    * preferably a triplet matrix.
    * \param M the NumericsMatrix
    * \param i row index
    * \param j column index
    * \param val the value to be inserted.
    */
-  void NM_zentry(NumericsMatrix* M, int i, int j, double val);
+  void NM_entry(NumericsMatrix* M, int i, int j, double val);
 
   /** get the value of a NumericsMatrix.
    * \param M the NumericsMatrix
@@ -302,8 +396,6 @@ extern "C"
    */
   bool NM_compare(NumericsMatrix* A, NumericsMatrix* B, double tol);
 
-
-
   /** return the number of non-zero element. For a dense matrix, it is the
    * product of the dimensions (e.g. an upper bound). For a sparse matrix, it is the true number
    * \param M the matrix
@@ -409,8 +501,6 @@ extern "C"
   void NM_row_prod_no_diag3(size_t sizeX, int block_start, size_t row_start, NumericsMatrix* A, double* x, double* y, bool init);
 
 
-
-
   void NM_row_prod_no_diag1x1(size_t sizeX, int block_start, size_t row_start, NumericsMatrix* A, double* x, double* y, bool init);
 
   /** Matrix vector multiplication : y = alpha A x + beta y
@@ -441,8 +531,6 @@ extern "C"
    */
   RawNumericsMatrix * NM_multiply(NumericsMatrix* A, NumericsMatrix* B);
 
-
-
   /** Transposed matrix multiplication : y += alpha transpose(A) x + y
    * \param[in] alpha scalar
    * \param[in] A a NumericsMatrix
@@ -463,7 +551,7 @@ extern "C"
   /** matrix and vector display *********************/
   /**************************************************/
 
-  void NM_dense_to_sparse(const NumericsMatrix* const A, NumericsMatrix* B);
+  void NM_dense_to_sparse(const NumericsMatrix* const A, NumericsMatrix* B, double threshold);
 
   /** Copy a NumericsMatrix into another with dense storage.
       \param A source matrix (any kind of storage)
@@ -613,7 +701,7 @@ extern "C"
 
 
 
-  /** Direct computation of the solution of a real system of linear
+  /** XXXXXX: to be rewritten Direct computation of the solution of a real system of linear
    * equations: A x = b. The factorized matrix A is kept for future solve.
    * If A is already factorized, the solve the linear system from it
    * \warning this is not enable for all the solvers, your mileage may vary
@@ -627,16 +715,55 @@ extern "C"
    * \return 0 if successful, else the error is specific to the backend solver
    * used
    */
+
+  /* LU factorization of the matrix. If the matrix has already been
+   * factorized (i.e if NM_LU_factorized(A) return true), nothing is
+   * done. To force a new factorization one has to set factorization
+   * flag to false : NM_set_LU_factorized(A, false) before the call to
+   * NM_LU_factorize.
+   * If the matrix is preserved, that means that a call to
+   * NM_preserve(A) has been done before the call to NM_LU_factorize,
+   * it is not destroyed, but the factorized part remains accessible for
+   * subsequent calls to NM_LU_solve.
+   * If the matrix is not preserved, then it is replaced by the
+   * factorized part.
+   * \param[in] A the NumericsMatrix
+   * \return an int, 0 means the matrix has been factorized. */
+  int NM_LU_factorize(NumericsMatrix* A);
+  int NM_Cholesky_factorize(NumericsMatrix* A);
+  int NM_LDLT_factorize(NumericsMatrix* A);
+
+  /* Solve linear system with multiple right hand size. A call to
+   * NM_LU_factorize is done at the beginning.
+
+   * \param[in] A the NumericsMatrix. A is not destroyed if it has
+   * been preserved by a call to NM_preserve(A).
+
+   * \param[in,out] b the right hand size which is a pointer on a
+   * matrix of double. It is replaced by the solutions
+
+   * \param[in] nrhs the number of right hand side.
+   * \return 0 if the solve succeeded.
+   */
+  int NM_LU_solve(NumericsMatrix* A,  double *b, unsigned int nrhs);
+  int NM_LU_solve_matrix_rhs(NumericsMatrix* Ao, NumericsMatrix* B);
+  int NM_Cholesky_solve(NumericsMatrix* A,  double *b, unsigned int nrhs);
+  int NM_Cholesky_solve_matrix_rhs(NumericsMatrix* Ao, NumericsMatrix* B);
+  int NM_LDLT_solve(NumericsMatrix* A,  double *b, unsigned int nrhs);
+
+
   int NM_gesv_expert(NumericsMatrix* A, double *b, unsigned keep);
   int NM_posv_expert(NumericsMatrix* A, double *b, unsigned keep);
 
   int NM_gesv_expert_multiple_rhs(NumericsMatrix* A, double *b, unsigned int n_rhs, unsigned keep);
 
+
+
   /**  Computation of the inverse of a NumericsMatrix A usinf NM_gesv_expert
    * \param[in,out] A a NumericsMatrix.
    * \return the matrix inverse.
    */
-  NumericsMatrix* NM_inv(NumericsMatrix* A);
+  NumericsMatrix* NM_LU_inv(NumericsMatrix* A);
 
   int NM_inverse_diagonal_block_matrix_in_place(NumericsMatrix* A);
 
@@ -655,12 +782,17 @@ extern "C"
     return NM_gesv_expert(A, b, preserve ? NM_PRESERVE : NM_NONE);
   }
 
+  /**  Computation of the inverse of a NumericsMatrix A usinf NM_gesv_expert
+   * \param[in,out] A a NumericsMatrix.
+   * \return the matrix inverse.
+   */
+  NumericsMatrix* NM_gesv_inv(NumericsMatrix* A);
 
   /** Set the linear solver
    * \param A the matrix
-   * \param solver_id the solver
+   * \param solver_id id of the solver
    */
-  void NM_setSparseSolver(NumericsMatrix* A, unsigned solver_id);
+  void NM_setSparseSolver(NumericsMatrix* A, NSM_linear_solver solver_id);
 
   /** Get Matrix internal data with initialization if needed.
    * \param[in,out] A a NumericsMatrix.
@@ -678,7 +810,6 @@ extern "C"
    */
   void NM_internalData_copy(const NumericsMatrix* const A, NumericsMatrix* B );
 
-
   /** Integer work vector initialization, if needed.
    * \param[in,out] A pointer on a NumericsMatrix.
    * \param[in] size number of element to allocate
@@ -701,6 +832,13 @@ extern "C"
    */
   void NM_add_to_diag3(NumericsMatrix* M, double alpha);
 
+  /** Add a constant term to the diagonal elements, when the block of the SBM
+   * are 5x5
+   * \param M the matrix
+   * \param alpha the term to add
+   */
+  void NM_add_to_diag5(NumericsMatrix* M, double alpha);
+
   /** Add two matrices with coefficients C = alpha*A + beta*B
    * \param alpha the first coefficient
    * \param A the first  matrix
@@ -720,7 +858,7 @@ extern "C"
    * \param type expected type
    * \param M the matrix to check
    */
-    static inline void NM_assert(const int type, NumericsMatrix* M)
+    static inline void NM_assert(NM_types type, NumericsMatrix* M)
   {
 #ifndef NDEBUG
     assert(M && "NM_assert :: the matrix is NULL");
@@ -819,6 +957,63 @@ extern "C"
   BalancingMatrices * NM_BalancingMatrices_new(NumericsMatrix* A);
 
 
+  /* free a Balancing Matrices structure
+   */
+  BalancingMatrices * NM_BalancingMatrices_free(BalancingMatrices* A);
+
+  /* Reset the version of a NM_types storage.
+   *\param M the NumericsMatrix,
+   *\param id the NM_types storage
+   */
+  void NM_reset_version(NumericsMatrix* M, NM_types id);
+
+  /* Reset versions of all storages.
+   *\param M the NumericsMatrix
+   */
+  void NM_reset_versions(NumericsMatrix* M);
+
+
+#ifdef WITH_OPENSSL
+  /* Compute sha1 hash of matrix values. Matrices of differents size and same
+   * values have the same hash.
+   * \param[in] A the matrix
+   * \param[in,out] digest an allocated space of size SHA_DIGEST_LENGTH
+   */
+  void NM_compute_values_sha1(NumericsMatrix* A, unsigned char * digest);
+
+  /* Get stored sha1 hash of a matrix.
+   * \param[in] A the matrix
+   * \return a pointer on the current raw sha1 hash
+   */
+  unsigned char* NM_values_sha1(NumericsMatrix* A);
+
+   /* Set sha1 hash of a matrix. Matrices of differents size and same
+   * values have the same hash.
+   * \param[in] A the matrix
+   */
+  void NM_set_values_sha1(NumericsMatrix* A);
+
+  /* Clear sha1 hash of a matrix.
+   * \param[in] A the matrix
+   */
+  void NM_clear_values_sha1(NumericsMatrix* A);
+
+  /* Check if matrix has beend modified after a previous NM_set_values_sha1.
+   * \param[in] A the NumericsMatrix
+   * \return true if the matrix is the same
+   */
+  bool NM_check_values_sha1(NumericsMatrix* A);
+
+  /* Compare two matrices with sha1. NM_set_values_sha1 must be called
+   * on the two matrices before.
+   * \param[in] A a NumericsMatrix
+   * \param[in] B a NumericsMatrix
+   * \return true if the matrices have the same values
+   */
+  bool NM_equal_values_sha1(NumericsMatrix* A, NumericsMatrix* B);
+
+#endif
+
 #if defined(__cplusplus) && !defined(BUILD_AS_CPP)
 }
 #endif
