@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
 */
-
+#include "CSparseMatrix_internal.h"     // for CSparseMatrix, CS_INT, cs_dl_spfree
 #include "NumericsSparseMatrix.h"
 #include <assert.h>            // for assert
 #ifndef __cplusplus
@@ -23,13 +23,13 @@
 #endif
 #include <stdio.h>             // for NULL, size_t, printf, fprintf, fscanf
 #include <stdlib.h>            // for free, exit, malloc, realloc, EXIT_FAILURE
-#include "CSparseMatrix_internal.h"     // for CSparseMatrix, CS_INT, cs_dl_spfree
+
 #include "NumericsMatrix.h"    // for NumericsMatrix, NM_csc, numericsSparse...
 #include "SiconosConfig.h"     // for HAVE_SORT
 /* #define DEBUG_NOCOLOR */
 /* #define DEBUG_STDOUT */
 /* #define DEBUG_MESSAGES */
-#include "debug.h"             // for DEBUG_BEGIN, DEBUG_END, DEBUG_EXPR
+#include "siconos_debug.h"             // for DEBUG_BEGIN, DEBUG_END, DEBUG_EXPR
 #include "numerics_verbose.h"  // for numerics_error_nonfatal, CHECK_IO
 #include "string.h"            // for memcpy, memset
 
@@ -68,6 +68,79 @@ static int sort_indices_struct_cmp(const void *a, const void *b)
 #pragma GCC diagnostic pop
 #endif
 
+version_t NSM_version(const NumericsSparseMatrix* M, NSM_t type)
+{
+  return NDV_value(&(M->versions[type]));
+}
+
+void NSM_set_version(NumericsSparseMatrix* M, NSM_t type,
+                     version_t value)
+{
+  NDV_set_value(&(M->versions[type]), value);
+}
+
+
+void NSM_inc_version(NumericsSparseMatrix* M, NSM_t type)
+{
+  version_t new_version = NSM_max_version(M) + 1;
+  NSM_set_version(M, type, new_version);
+}
+
+/* internal compare function */
+static inline NSM_t nsm_max(const NumericsSparseMatrix* M,
+                               NSM_t type1,
+                               NSM_t type2)
+{
+  return NSM_version(M, type1) > NSM_version(M, type2) ?
+    type1 : type2;
+}
+
+NSM_t NSM_latest_id(const NumericsSparseMatrix* M)
+{
+  assert(M);
+
+  return (nsm_max(M, nsm_max(M, nsm_max(M, NSM_TRIPLET,
+                                        NSM_HALF_TRIPLET),
+                             NSM_CSC),
+                  NSM_CSR));
+}
+
+version_t NSM_max_version(const NumericsSparseMatrix* M)
+{
+  return NSM_version(M, NSM_latest_id(M));
+}
+
+
+CSparseMatrix* NSM_latest(const NumericsSparseMatrix* M)
+{
+  assert(M);
+
+  switch (NSM_latest_id(M))
+  {
+  case NSM_TRIPLET: return M->triplet;
+  case NSM_HALF_TRIPLET: return M->half_triplet;
+  case NSM_CSR: return M->csr;
+  case NSM_CSC: return M->csc;
+  default:
+    numerics_error("NSM_latest", "unknown matrix type");
+  }
+  return 0;
+}
+
+void NSM_reset_version(NumericsSparseMatrix*M, NSM_t id)
+{
+  NDV_reset(&(M->versions[id]));
+}
+
+void NSM_reset_versions(NumericsSparseMatrix* M)
+{
+  NSM_reset_version(M, NSM_TRIPLET);
+  NSM_reset_version(M, NSM_HALF_TRIPLET);
+  NSM_reset_version(M, NSM_CSC);
+  NSM_reset_version(M, NSM_CSR);
+}
+
+
 void NSM_null(NumericsSparseMatrix* A)
 {
   A->linearSolverParams = NULL;
@@ -78,10 +151,16 @@ void NSM_null(NumericsSparseMatrix* A)
   A->csr = NULL;
   A->diag_indx = NULL;
   A->origin = NSM_UNKNOWN;
+
+  NSM_reset_versions(A);
 }
 
 double* NSM_data(NumericsSparseMatrix* A)
 {
+  // assert (NSM_latest_id(A) == A->origin);
+  assert (NSM_version(A, A->origin) ==
+            NSM_version(A, NSM_latest_id(A)));
+
   switch(A->origin)
   {
   case NSM_CSC:
@@ -162,10 +241,134 @@ NumericsSparseMatrix* NSM_clear(NumericsSparseMatrix* A)
     free(A->diag_indx);
     A->diag_indx = NULL;
   }
+
+  NSM_reset_versions(A);
+
   return NULL;
 }
 
 
+
+
+void NSM_copy(NumericsSparseMatrix* A, NumericsSparseMatrix* B)
+{
+
+  assert(A);
+  assert(B);
+
+  B->origin = A->origin;
+
+  CSparseMatrix* A_;
+  CSparseMatrix* B_;
+
+  switch(A->origin)
+  {
+  case NSM_TRIPLET:
+  {
+    A_ = A->triplet;
+
+    if(!B->triplet)
+    {
+      B->triplet = cs_spalloc(A_->m, A_->n, A_->nzmax, 0, 1);
+    }
+
+    B_ = B->triplet;
+    NSM_set_version(B, NSM_TRIPLET,
+                    NSM_version(A, NSM_TRIPLET));
+    break;
+  }
+  case NSM_HALF_TRIPLET:
+  {
+    A_ = A->half_triplet;
+
+    if(!B->half_triplet)
+    {
+      B->half_triplet = cs_spalloc(A_->m, A_->n, A_->nzmax, 0, 1);
+    }
+
+    B_ = B->half_triplet;
+    NSM_set_version(B,
+                    NSM_HALF_TRIPLET,
+                    NSM_version(A,
+                                NSM_HALF_TRIPLET));
+    break;
+  }
+  case NSM_CSC:
+  {
+    assert(A->csc);
+
+    A_ = A->csc;
+
+    if(!B->csc)
+    {
+      B->csc = cs_spalloc(A_->m, A_->n, A_->nzmax, 0, 0);
+    }
+
+    B_ = B->csc;
+    NSM_set_version(B, NSM_CSC, NSM_version(A,
+                                            NSM_CSC));
+    break;
+  }
+  case NSM_CSR:
+  {
+    assert(A->csr);
+
+    A_ = A->csr;
+
+    if(!B->csr)
+    {
+      B->csr = cs_spalloc(A_->m, A_->n, A_->nzmax, 1, 0);
+      B->csr->nz = -2;
+      B->csr->m = A_->m;
+      B->csr->n = A_->n;
+    }
+
+    B_ = B->csr;
+    NSM_set_version(B, NSM_CSR, NSM_version(A,
+                                            NSM_CSR));
+    break;
+  }
+  default:
+  {
+    fprintf(stderr, "NSM_copy :: error unknown origin %u for sparse matrix\n", A->origin);
+    exit(EXIT_FAILURE);
+  }
+  }
+  CSparseMatrix_copy(A_, B_);
+
+  /* diag_indx   */
+  /* We remove diag_indx from B and  we copy it from A if it exists */
+  if(B->diag_indx)
+  {
+    free(B->diag_indx);
+    B->diag_indx=NULL;
+  }
+  if(A->diag_indx)
+  {
+    B->diag_indx = (CS_INT*) malloc((size_t)A_->m * sizeof(CS_INT));
+    memcpy(B->diag_indx, A->diag_indx, (size_t)A_->m * sizeof(CS_INT));
+  }
+
+
+  /*  NSM_linear_solver_params */
+  if(B->linearSolverParams)
+  {
+    NSM_linearSolverParams_free(B->linearSolverParams);
+    B->linearSolverParams=NULL;
+  }
+  /* We copy only the id of the solver to keep track of if NM_preserve is used before
+   * factorization. The remaining part is not copied since we have blind pointer.
+   */
+  if(A->linearSolverParams)
+  {
+    B->linearSolverParams = NSM_linearSolverParams_new();
+    B->linearSolverParams->solver =A->linearSolverParams->solver;
+    B->linearSolverParams->LDLT_solver =A->linearSolverParams->LDLT_solver;
+  }
+
+}
+
+
 NSM_linear_solver_params* NSM_linearSolverParams_new(void)
 {
   NSM_linear_solver_params* p = (NSM_linear_solver_params*)
@@ -182,7 +385,12 @@ NSM_linear_solver_params* NSM_linearSolverParams_new(void)
 #elif defined(WITH_MKL_PARDISO)
   p->solver = NSM_MKL_PARDISO;
 #else
-  p->solver = NSM_CS_LUSOL;
+  p->solver = NSM_CSPARSE;  // default solver
+#endif
+
+  p->LDLT_solver = p->solver;
+#if defined(WITH_MA57)
+  p->LDLT_solver = NSM_HSL;
 #endif
 
   p->linear_solver_data = NULL;
@@ -198,6 +406,8 @@ NSM_linear_solver_params* NSM_linearSolverParams_new(void)
   return p;
 }
 
+
+
 NSM_linear_solver_params* NSM_linearSolverParams(NumericsMatrix* A)
 {
   if(!numericsSparseMatrix(A)->linearSolverParams)
@@ -352,6 +562,26 @@ void NSM_fix_csc(CSparseMatrix* A)
     s = NULL;
   }
 }
+
+void NSM_sort_csc(CSparseMatrix* A)
+{
+
+  CSparseMatrix * AT = cs_transpose(A,1);
+  CSparseMatrix * ATT = cs_transpose(AT,1);
+  cs_spfree(AT);
+
+  free(A->i);
+  free(A->x);
+  A->i = ATT->i;
+  A->x = ATT->x;
+
+  ATT->i=NULL;
+  ATT->x=NULL;
+
+  cs_spfree(ATT);
+}
+
+
 int NSM_to_dense(const NumericsSparseMatrix* const A, double * B)
 {
 
@@ -367,9 +597,11 @@ unsigned NSM_origin(const NumericsSparseMatrix* M)
 {
   assert(M);
   if(!M) return -1;
+  assert (NSM_version(M, NSM_latest_id(M)) == NSM_version(M, M->origin));
   return M->origin;
 }
 
+
 CSparseMatrix* NSM_get_origin(const NumericsSparseMatrix* M)
 {
   assert(M);
@@ -402,7 +634,7 @@ void NSM_write_in_file(const NumericsSparseMatrix* m, FILE* file)
 NumericsSparseMatrix * NSM_new_from_file(FILE* file)
 {
   int info;
-  int _origin =0;
+  NSM_t _origin =0;
   CHECK_IO(fscanf(file, "%d", &_origin), &info);
   NumericsSparseMatrix * out = NSM_new();
   out->origin = _origin;
@@ -414,6 +646,7 @@ NumericsSparseMatrix * NSM_new_from_file(FILE* file)
     assert(out->origin ==NSM_TRIPLET);
     out->triplet = C;
     out->origin = NSM_TRIPLET;
+    NSM_inc_version(out, NSM_TRIPLET);
   }
   else
   {
@@ -421,11 +654,18 @@ NumericsSparseMatrix * NSM_new_from_file(FILE* file)
     {
       out->csc = C;
       out->origin = NSM_CSC;
+      NSM_inc_version(out, NSM_CSC);
     }
     else if(out->origin == NSM_CSR)
     {
       out->csr = C;
       out->origin = NSM_CSR;
+      NSM_inc_version(out, NSM_CSR);
+    }
+    else if(out->origin == NSM_HALF_TRIPLET)
+    {
+      out->half_triplet = C;
+      NSM_inc_version(out, NSM_HALF_TRIPLET);
     }
   }
   return out;
@@ -433,7 +673,7 @@ NumericsSparseMatrix * NSM_new_from_file(FILE* file)
 
 NumericsSparseMatrix * NSM_triplet_eye(unsigned int size)
 {
-  int _origin = NSM_TRIPLET;
+  NSM_t _origin = NSM_TRIPLET;
   NumericsSparseMatrix * out = NSM_new();
   out->origin = _origin;
 
@@ -449,6 +689,7 @@ NumericsSparseMatrix * NSM_triplet_eye(unsigned int size)
   assert(out->origin ==NSM_TRIPLET);
   out->triplet = C;
   out->origin = NSM_TRIPLET;
+  NSM_inc_version(out, NSM_TRIPLET);
   return out;
 }
 
@@ -459,7 +700,7 @@ static CS_INT* NSM_diag_indices_trivial(NumericsMatrix* M)
   assert(A);
   if(A->diag_indx) return A->diag_indx;
 
-  CS_INT* indices = (CS_INT*) malloc(M->size0 * sizeof(CS_INT));
+  CS_INT* indices = (CS_INT*) malloc((size_t)M->size0 * sizeof(CS_INT));
   A->diag_indx = indices;
   /* XXX hack --xhub  */
   if(A->origin == NSM_TRIPLET)
@@ -527,7 +768,7 @@ CS_INT* NSM_diag_indices(NumericsMatrix* M)
    * on the existence  of the diagonal elements. This makes sure that the matrix is replaced
    * by one that has all diagonal elements. The copy of the matrix could be optimized. */
 
-  indices = (CS_INT*) malloc(M->size0 * sizeof(CS_INT));
+  indices = (CS_INT*) malloc((size_t)M->size0 * sizeof(CS_INT));
   A->diag_indx = indices;
   /* XXX hack --xhub  */
   if(A->origin == NSM_TRIPLET)
@@ -553,34 +794,34 @@ CS_INT* NSM_diag_indices(NumericsMatrix* M)
     Np[0] = 0;
     if(Ai[0] == 0)
     {
-      memcpy(Ni, Ai, end*sizeof(CS_INT));
+      memcpy(Ni, Ai, (size_t)end*sizeof(CS_INT));
       Np[1] = Ap[1];
-      memcpy(Nx, Ax, end*sizeof(double));
+      memcpy(Nx, Ax, (size_t)end*sizeof(double));
     }
     else
     {
       Ni[0] = 0;
       Np[1] = Ap[1] + 1;
       Nx[0] = 0.;
-      memcpy(&Ni[1], Ai, end*sizeof(CS_INT));
-      memcpy(&Nx[1], Ax, end*sizeof(double));
+      memcpy(&Ni[1], Ai, (size_t)end*sizeof(CS_INT));
+      memcpy(&Nx[1], Ax, (size_t)end*sizeof(double));
       ++inc;
     }
 
     /* Could optimize further and copy everything using memcpy */
-    for(size_t j = 1; j < (size_t)M->size0; ++j)
+    for(CS_INT j = 1; j < M->size0; ++j)
     {
       CS_INT rem = 0;
       for(CS_INT p = Ap[j]; (rem == 0) && (p < Ap[j+1]); ++p)
       {
-        if(Ai[p] < (CS_INT) j)
+        if(Ai[p] <  j)
         {
           Ni[p+inc] = Ai[p];
           Nx[p+inc] = Ax[p];
         }
         else
         {
-          if(Ai[p] > (CS_INT) j)
+          if(Ai[p] >  j)
           {
             Ni[p+inc] = j;
             Nx[p+inc] = 0.;
@@ -595,8 +836,8 @@ CS_INT* NSM_diag_indices(NumericsMatrix* M)
           Np[j] = Ap[j] + inc;
         }
         end = Ap[j+1] - rem;
-        memcpy(&Ni[rem+inc], &Ai[rem], end*sizeof(CS_INT));
-        memcpy(&Nx[rem+inc], &Ax[rem], end*sizeof(double));
+        memcpy(&Ni[rem+inc], &Ai[rem], (size_t)end*sizeof(CS_INT));
+        memcpy(&Nx[rem+inc], &Ax[rem], (size_t)end*sizeof(double));
         assert(inc <= M->size0);
       }
     }
@@ -650,6 +891,8 @@ void NSM_extract_block(NumericsMatrix* M, double* blockM, size_t pos_row, size_t
         for(CS_INT p = Mp[j]; p < Mp[j+1]; ++p)
         {
           CS_INT row_nb = Mi[p];
+          /* Warning : the following strategy work only if the csc storage is
+             correclty ordered. Use NSM_fix_csc to be sure*/
           if(row_nb >= (CS_INT) pos_row)
           {
             if(row_nb >= (CS_INT)(pos_row + block_row_size))
