@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -112,7 +112,7 @@ static SolverOptions* solver_options_initialize(int solver_id, int iter_max, dou
 static void recursive_solver_options_print(SolverOptions* options, int level)
 {
   char* marge;
-  marge = (char*) malloc((level + 1) * sizeof(char));
+  marge = (char*) malloc((size_t)(level + 1) * sizeof(char));
   for(int i = 0; i < level; i++)
     marge[i] = ' ';
   marge[level] = '\0';
@@ -141,7 +141,7 @@ static void recursive_solver_options_print(SolverOptions* options, int level)
       numerics_printf("%snon zero double parameters in options->dparam:", marge);
       for(int i = 0; i < options->dSize; ++i)
       {
-        if(options->dparam[i]) numerics_printf("%s\t\t\t\t\t\t options->dparam[%i] = %.6le", marge, i, options->dparam[i]);
+        if(options->dparam[i]>0.) numerics_printf("%s\t\t\t\t\t\t options->dparam[%i] = %.6le", marge, i, options->dparam[i]);
       }
     }
   }
@@ -238,7 +238,8 @@ void solver_options_delete(SolverOptions* op)
 
     op->isSet = false;
   }
-  free(op);
+//  double free or corruption
+//  free(op);
 }
 
 SolverOptions * solver_options_copy(SolverOptions* source)
@@ -697,6 +698,12 @@ SolverOptions * solver_options_create(int solverId)
     rfc3d_nsgs_set_default(options);
     break;
   }
+  case SICONOS_ROLLING_FRICTION_3D_ADMM:
+  {
+    options = solver_options_initialize(solverId, 1000, 1e-4, 0);
+    rolling_fc3d_admm_set_default(options);
+    break;
+  }
   case SICONOS_ROLLING_FRICTION_2D_NSGS:
   {
     options = solver_options_initialize(solverId, 1000, 1e-4, 1);
@@ -882,6 +889,12 @@ SolverOptions * solver_options_create(int solverId)
     rfc2d_poc_withLocalIteration_set_default(options);
     break;
   }
+  case SICONOS_GLOBAL_ROLLING_FRICTION_3D_NSGS_WR:
+  {
+    options = solver_options_initialize(solverId, 1000, 1e-12, 1);
+    rfc3d_nsgs_set_default(options);
+    break;
+  }
 
 
   case SICONOS_FRICTION_3D_NCPGlockerFBFixedPoint:
@@ -901,7 +914,7 @@ SolverOptions * solver_options_create(int solverId)
   // --- GMP Solver ---
   case SICONOS_GENERIC_MECHANICAL_NSGS:
   {
-    options = solver_options_initialize(solverId, 10000, 1e-4, 3);
+    options = solver_options_initialize(solverId, 10000, 1e-4, 4);
     gmp_set_default(options);
     break;
   }
@@ -957,3 +970,15 @@ SolverOptions * solver_options_get_internal_solver(SolverOptions * options, size
     return options->internalSolvers[n];
 }
 
+void solver_options_set_internal_solver(SolverOptions * options, size_t n, SolverOptions* NSO)
+{
+  if(n+1 > options->numberOfInternalSolvers)
+  {
+    printf("solver_options_set_internal_solver : the index must be between 0 and  options->numberOfInternalSolvers -1 ");
+  }
+  else
+  {
+    options->internalSolvers[n] = NSO;
+  }
+}
+
