@@ -1,7 +1,7 @@
 /* Siconos is a program dedicated to modeling, simulation and control
  * of non smooth dynamical systems.
  *
- * Copyright 2020 INRIA.
+ * Copyright 2021 INRIA.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,6 +24,7 @@
 #include "NumericsFwd.h"    // for SparseBlockStructuredMatrix, SparseBlockC...
 
 #include "SiconosConfig.h" // for BUILD_AS_CPP // IWYU pragma: keep
+#include "NumericsDataVersion.h" // versioning
 
 /*!\file SparseBlockMatrix.h
   \brief Structure definition and functions related to
@@ -52,7 +53,7 @@
     \param *blocksize0 the list of sums of the number of rows of the
     first column of blocks of M: blocksize0[i] = blocksize0[i-1] +
     ni, ni being the number of rows of the block at row i
-    *blocksize1 the list of sums of the number of columns of the
+    \param *blocksize1 the list of sums of the number of columns of the
     first row of blocks of M: blocksize1[i] = blocksize1[i-1] + ni,
     ni being the number of columns of the block at column i
     \param filled1 index of the last non empty line + 1
@@ -120,7 +121,7 @@ struct SparseBlockStructuredMatrix
 
   /* the index of the last non empty line + 1 */
   size_t filled1;
-  /* the size of index2_data that corresponds of the number of non null blocks*/
+  /* the size of index2_data that corresponds to the number of non null blocks*/
   size_t filled2;
 
   size_t *index1_data;
@@ -129,6 +130,7 @@ struct SparseBlockStructuredMatrix
   /* the indices of the diagonal blocks */
   unsigned int * diagonal_blocks;
 
+  NumericsDataVersion version; /**< version of storage */
 };
 
 struct SparseBlockCoordinateMatrix
@@ -402,7 +404,15 @@ extern "C"
   */
   unsigned int SBM_diagonal_block_index(SparseBlockStructuredMatrix* const M, unsigned int row);
 
-  int SBM_zentry(const SparseBlockStructuredMatrix* const M, unsigned int row, unsigned int col, double val);
+  /** insert an entry into a SparseBlockStructuredMatrix.
+   *  This method is expensive in terms of memory management. For a lot of entries, use
+   * an alternative
+   * \param M the SparseBlockStructuredMatrix
+   * \param i row index
+   * \param j column index
+   * \param val the value to be inserted.
+   */
+  int SBM_entry(SparseBlockStructuredMatrix* M, unsigned int row, unsigned int col, double val);
 
   /** get the element of row i and column j of the matrix M
      \param M the SparseBlockStructuredMatrix matrix
